pub struct DockManager {
pub state: DockManagerState,
pub docks: IndexMap<String, Box<dyn Dock>>,
pub editor_canvases: IndexMap<String, usize>,
pub editor_docks: IndexMap<String, Box<dyn Dock>>,
pub dock: String,
pub index: usize,
pub editor_index: Option<usize>,
pub supports_undo: bool,
}Fields
state: DockManagerStatedocks: IndexMap<String, Box<dyn Dock>>editor_canvases: IndexMap<String, usize>editor_docks: IndexMap<String, Box<dyn Dock>>dock: Stringindex: usizeeditor_index: Option<usize>supports_undo: boolImplementations
Sourceimpl DockManager
impl DockManager
pub fn new() -> Self
pub fn init(&mut self, ctx: &mut TheContext) -> TheCanvas
pub fn set_dock( &mut self, dock: String, ui: &mut TheUI, ctx: &mut TheContext, project: &Project, server_ctx: &mut ServerContext, )
pub fn import( &mut self, content: String, ui: &mut TheUI, ctx: &mut TheContext, project: &mut Project, server_ctx: &mut ServerContext, )
pub fn export(&self) -> Option<String>
pub fn handle_event( &mut self, event: &TheEvent, ui: &mut TheUI, ctx: &mut TheContext, project: &mut Project, server_ctx: &mut ServerContext, ) -> bool
Sourcepub fn get_state(&self) -> DockManagerState
pub fn get_state(&self) -> DockManagerState
Returns the state of the dock manager.
Sourcepub fn add_editors_to_stack(
&mut self,
stack: &mut TheStackLayout,
ctx: &mut TheContext,
)
pub fn add_editors_to_stack( &mut self, stack: &mut TheStackLayout, ctx: &mut TheContext, )
Add the dock editors to the stack and maps.
Sourcepub fn edit_maximize(
&mut self,
ui: &mut TheUI,
ctx: &mut TheContext,
project: &mut Project,
server_ctx: &mut ServerContext,
)
pub fn edit_maximize( &mut self, ui: &mut TheUI, ctx: &mut TheContext, project: &mut Project, server_ctx: &mut ServerContext, )
Shows the editor of the current dock if available, otherwise maximizes the dock.
Sourcepub fn minimize(&mut self, ui: &mut TheUI, ctx: &mut TheContext)
pub fn minimize(&mut self, ui: &mut TheUI, ctx: &mut TheContext)
Shows the editor of the current dock if available, otherwise maximizes the dock.
Sourcepub fn current_dock_supports_undo(&self) -> bool
pub fn current_dock_supports_undo(&self) -> bool
Returns true if the current dock (either the editor dock or the normal dock) supports undo.
pub fn undo( &mut self, ui: &mut TheUI, ctx: &mut TheContext, project: &mut Project, server_ctx: &mut ServerContext, )
pub fn redo( &mut self, ui: &mut TheUI, ctx: &mut TheContext, project: &mut Project, server_ctx: &mut ServerContext, )
Sourcepub fn current_dock_supports_minimap_animation(&self) -> bool
pub fn current_dock_supports_minimap_animation(&self) -> bool
Returns true if the current (visible) dock needs animated minimap updates.
Sourcepub fn get_active_dock(&self) -> Option<&dyn Dock>
pub fn get_active_dock(&self) -> Option<&dyn Dock>
Get the currently active dock (editor dock if in editor mode, otherwise the current dock)
Sourcepub fn has_dock_changes(&self) -> bool
pub fn has_dock_changes(&self) -> bool
Check if any dock has unsaved changes in its undo stack
Sourcepub fn mark_saved(&mut self)
pub fn mark_saved(&mut self)
Mark all dock-local undo states as saved.
pub fn apply_debug_data( &mut self, ui: &mut TheUI, ctx: &mut TheContext, project: &Project, server_ctx: &ServerContext, debug: &DebugModule, )