pub enum TheVLayoutMode {
ContentBased,
SizeBased,
}Expand description
The layout mode.
Variants
ContentBased
Lays out the content based on their limiter settings (the default).
SizeBased
Distributes the content evenly based on the available space.