TheValue

Enum TheValue 

pub enum TheValue {
Show 31 variants Empty, Bool(bool), Float(f32), FloatRange(f32, RangeInclusive<f32>), Int(i32), IntRange(i32, RangeInclusive<i32>), Text(String), TextList(i32, Vec<String>), Char(char), Int2(Vec2<i32>), Float2(Vec2<f32>), Int3(Vec3<i32>), Float3(Vec3<f32>), Int4(Vec4<i32>), Float4(Vec4<f32>), Position(Vec3<f32>), Tile(String, Uuid), KeyCode(TheKeyCode), RangeI32(RangeInclusive<i32>), RangeF32(RangeInclusive<f32>), ColorObject(TheColor), PaletteIndex(u16), Comparison(TheValueComparison), Assignment(TheValueAssignment), Id(Uuid), Direction(Vec3<f32>), List(Vec<TheValue>), Time(TheTime), TimeDuration(TheTime, TheTime), TileMask(TheTileMask), Image(TheRGBABuffer),
}
TheValue contains all possible values used by widgets and layouts. Encapsulating them in an enum alllows easy transfer and comparison of values.

Variants



Empty



Bool(bool)



Float(f32)



FloatRange(f32, RangeInclusive<f32>)



Int(i32)



IntRange(i32, RangeInclusive<i32>)



Text(String)



TextList(i32, Vec<String>)



Char(char)



Int2(Vec2<i32>)



Float2(Vec2<f32>)



Int3(Vec3<i32>)



Float3(Vec3<f32>)



Int4(Vec4<i32>)



Float4(Vec4<f32>)



Position(Vec3<f32>)



Tile(String, Uuid)



KeyCode(TheKeyCode)



RangeI32(RangeInclusive<i32>)



RangeF32(RangeInclusive<f32>)



ColorObject(TheColor)



PaletteIndex(u16)



Comparison(TheValueComparison)



Assignment(TheValueAssignment)



Id(Uuid)



Direction(Vec3<f32>)



List(Vec<TheValue>)



Time(TheTime)



TimeDuration(TheTime, TheTime)



TileMask(TheTileMask)



Image(TheRGBABuffer)

Implementations

Source

impl TheValue

pub fn to_vec2i(&self) -> Option<Vec2<i32>>

pub fn to_vec2f(&self) -> Option<Vec2<f32>>

pub fn to_vec3f(&self) -> Option<Vec3<f32>>

pub fn to_i32(&self) -> Option<i32>

pub fn to_f32(&self) -> Option<f32>

pub fn to_string(&self) -> Option<String>

pub fn to_char(&self) -> Option<char>

pub fn to_key_code(&self) -> Option<TheKeyCode>

pub fn to_range_i32(&self) -> Option<RangeInclusive<i32>>

pub fn to_range_f32(&self) -> Option<RangeInclusive<f32>>

pub fn to_color(&self) -> Option<TheColor>

pub fn as_f32(&self) -> Option<f32>

Returns the value as f32 if possible. Used for comparison.

pub fn as_i32(&self) -> Option<i32>

Returns the value as i32 if possible.

pub fn is_equal(&self, other: &TheValue) -> bool

Test if two values are equal.

pub fn is_greater_than(&self, other: &TheValue) -> bool

pub fn is_less_than(&self, other: &TheValue) -> bool

pub fn is_greater_than_or_equal(&self, other: &TheValue) -> bool

pub fn is_less_than_or_equal(&self, other: &TheValue) -> bool

pub fn add(&self, other: &TheValue) -> Option<TheValue>

pub fn sub(&self, other: &TheValue) -> Option<TheValue>

pub fn mul(&self, other: &TheValue) -> Option<TheValue>

pub fn div(&self, other: &TheValue) -> Option<TheValue>

pub fn modulus(&self, other: &TheValue) -> Option<TheValue>

pub fn to_kind(&self) -> String

Returns a description of the value as string.

pub fn describe(&self) -> String

Returns a description of the value as string.