pub struct MapMini {
pub offset: Vec2<f32>,
pub grid_size: f32,
pub dynamic_linedefs: Vec<CompiledLinedef>,
pub blocked_tiles: HashSet<Vec2<i32>, FxBuildHasher>,
/* private fields */
}Expand description
A miniature version of the Map used for client side lighting calculations during the rasterization process and server side collision detection etc.
Fields
offset: Vec2<f32>grid_size: f32dynamic_linedefs: Vec<CompiledLinedef>Dynamic blocking geometry (items, etc)
blocked_tiles: HashSet<Vec2<i32>, FxBuildHasher>Implementations
Sourceimpl MapMini
impl MapMini
pub fn empty() -> MapMini
pub fn new( offset: Vec2<f32>, grid_size: f32, linedefs: Vec<CompiledLinedef>, occluded_sectors: Vec<(BBox, f32)>, ) -> MapMini
Sourcepub fn get_occlusion(&self, at: Vec2<f32>) -> f32
pub fn get_occlusion(&self, at: Vec2<f32>) -> f32
Returns the sector occlusion at the given position.
Sourcepub fn segments_intersect(
&self,
a1: Vec2<f32>,
a2: Vec2<f32>,
b1: Vec2<f32>,
b2: Vec2<f32>,
) -> bool
pub fn segments_intersect( &self, a1: Vec2<f32>, a2: Vec2<f32>, b1: Vec2<f32>, b2: Vec2<f32>, ) -> bool
Returns true if the two segments intersect.
Sourcepub fn is_visible(&self, from: Vec2<f32>, to: Vec2<f32>) -> bool
pub fn is_visible(&self, from: Vec2<f32>, to: Vec2<f32>) -> bool
Test if “to” is visible from “from”.
Sourcepub fn is_visible_and_lit(&self, from: Vec2<f32>, to: Vec2<f32>) -> bool
pub fn is_visible_and_lit(&self, from: Vec2<f32>, to: Vec2<f32>) -> bool
Test if “to” is visible from “from” and if it is lit.
Sourcepub fn move_distance(
&self,
start_pos: Vec2<f32>,
move_vector: Vec2<f32>,
radius: f32,
) -> (Vec2<f32>, bool)
pub fn move_distance( &self, start_pos: Vec2<f32>, move_vector: Vec2<f32>, radius: f32, ) -> (Vec2<f32>, bool)
Returns target position (and if the move was blocked) and, if the move was blocked by an item, returns the item ID.