pub struct Aabb<T> {
pub min: Vec3<T>,
pub max: Vec3<T>,
}Expand description
Axis-aligned Bounding Box (3D), represented by min and max points.
N.B: You are responsible for ensuring that all respective elements of
min are indeed less than or equal to those of max.
The is_valid(), make_valid() and made_valid() methods are designed to help you
with this.
Fields
min: Vec3<T>Minimum coordinates of bounds.
max: Vec3<T>Maximum coordinates of bounds.
Implementations
Sourceimpl<T> Aabb<T>
impl<T> Aabb<T>
Sourcepub fn is_valid(&self) -> boolwhere
T: PartialOrd,
pub fn is_valid(&self) -> boolwhere
T: PartialOrd,
Is this bounding shape valid ?
True only if all elements of self.min are less than or equal to those of self.max.
Sourcepub fn make_valid(&mut self)where
T: PartialOrd,
pub fn make_valid(&mut self)where
T: PartialOrd,
Makes this bounding shape valid by swapping elements of self.min with self.max as needed.
Sourcepub fn made_valid(self) -> Aabb<T>where
T: PartialOrd,
pub fn made_valid(self) -> Aabb<T>where
T: PartialOrd,
Returns this bounding shape made valid by swapping elements of self.min with self.max as needed.
Sourcepub fn new_empty(p: Vec3<T>) -> Aabb<T>where
T: Copy,
pub fn new_empty(p: Vec3<T>) -> Aabb<T>where
T: Copy,
Creates a new bounding shape from a single point.
Sourcepub fn into_rect3(self) -> Rect3<T, T>
pub fn into_rect3(self) -> Rect3<T, T>
Converts this bounding shape to the matching rectangle representation.
Sourcepub fn union(self, other: Aabb<T>) -> Aabb<T>where
T: PartialOrd,
pub fn union(self, other: Aabb<T>) -> Aabb<T>where
T: PartialOrd,
Gets the smallest bounding shape that contains both this one and another.
Sourcepub fn intersection(self, other: Aabb<T>) -> Aabb<T>where
T: PartialOrd,
pub fn intersection(self, other: Aabb<T>) -> Aabb<T>where
T: PartialOrd,
Gets the largest bounding shape contained by both this one and another.
Sourcepub fn expand_to_contain(&mut self, other: Aabb<T>)where
T: Copy + PartialOrd,
pub fn expand_to_contain(&mut self, other: Aabb<T>)where
T: Copy + PartialOrd,
Sets this bounding shape to the union of itself with another.
Sourcepub fn intersect(&mut self, other: Aabb<T>)where
T: Copy + PartialOrd,
pub fn intersect(&mut self, other: Aabb<T>)where
T: Copy + PartialOrd,
Sets this bounding shape to the intersection of itself with another.
Sourcepub fn expanded_to_contain_point(self, p: Vec3<T>) -> Aabb<T>where
T: Copy + PartialOrd,
pub fn expanded_to_contain_point(self, p: Vec3<T>) -> Aabb<T>where
T: Copy + PartialOrd,
Gets a copy of this shape so that it contains the given point.
Sourcepub fn expand_to_contain_point(&mut self, p: Vec3<T>)where
T: Copy + PartialOrd,
pub fn expand_to_contain_point(&mut self, p: Vec3<T>)where
T: Copy + PartialOrd,
Expands this shape so that it contains the given point.
Sourcepub fn contains_point(self, p: Vec3<T>) -> boolwhere
T: PartialOrd,
pub fn contains_point(self, p: Vec3<T>) -> boolwhere
T: PartialOrd,
Does this bounding shape contain the given point ?
Sourcepub fn contains_aabb(self, other: Aabb<T>) -> boolwhere
T: PartialOrd,
pub fn contains_aabb(self, other: Aabb<T>) -> boolwhere
T: PartialOrd,
Does this bounding shape fully contain another ?
Sourcepub fn collides_with_aabb(self, other: Aabb<T>) -> boolwhere
T: PartialOrd,
pub fn collides_with_aabb(self, other: Aabb<T>) -> boolwhere
T: PartialOrd,
Does this bounding shape collide with another ?
Sourcepub fn collision_vector_with_aabb(self, other: Aabb<T>) -> Vec3<T>
pub fn collision_vector_with_aabb(self, other: Aabb<T>) -> Vec3<T>
Gets a vector that tells how much self penetrates other.
Sourcepub fn projected_point(self, p: Vec3<T>) -> Vec3<T>where
T: Clamp,
pub fn projected_point(self, p: Vec3<T>) -> Vec3<T>where
T: Clamp,
Project the given point into the bounding shape (equivalent to ‘snapping’ the point to the closest point in the bounding shape).
Sourcepub fn distance_to_point(self, p: Vec3<T>) -> T
pub fn distance_to_point(self, p: Vec3<T>) -> T
Get the smallest distance between the bounding shape and a point.
Sourcepub fn split_at_x(self, sp: T) -> [Aabb<T>; 2]where
T: Copy + PartialOrd,
pub fn split_at_x(self, sp: T) -> [Aabb<T>; 2]where
T: Copy + PartialOrd,
Splits this shape in two, by a straight plane along the
x
axis.
The returned tuple is (low, high).
Panics
sp is assumed to be a position along the
x
axis that is within this shape’s bounds.
Sourcepub fn split_at_y(self, sp: T) -> [Aabb<T>; 2]where
T: Copy + PartialOrd,
pub fn split_at_y(self, sp: T) -> [Aabb<T>; 2]where
T: Copy + PartialOrd,
Splits this shape in two, by a straight plane along the
y
axis.
The returned tuple is (low, high).
Panics
sp is assumed to be a position along the
y
axis that is within this shape’s bounds.
Sourcepub fn split_at_z(self, sp: T) -> [Aabb<T>; 2]where
T: Copy + PartialOrd,
pub fn split_at_z(self, sp: T) -> [Aabb<T>; 2]where
T: Copy + PartialOrd,
Splits this shape in two, by a straight plane along the
z
axis.
The returned tuple is (low, high).
Panics
sp is assumed to be a position along the
z
axis that is within this shape’s bounds.
Sourcepub fn map<D, F>(self, f: F) -> Aabb<D>where
F: FnMut(T) -> D,
pub fn map<D, F>(self, f: F) -> Aabb<D>where
F: FnMut(T) -> D,
Returns this bounding shape, converted element-wise using the given closure.
Sourcepub fn as_<D>(self) -> Aabb<D>where
T: AsPrimitive<D>,
D: 'static + Copy,
pub fn as_<D>(self) -> Aabb<D>where
T: AsPrimitive<D>,
D: 'static + Copy,
Converts this rectangle to a rectangle of another type, using the as conversion.