Sphere

Struct Sphere 

pub struct Sphere<P, E> {
    pub center: Vec3<P>,
    pub radius: E,
}
Sphere (3D), represented by center and radius.

Fields

center: Vec3<P>radius: E

Implementations

Source

impl<P, E> Sphere<P, E>

pub fn surface_area(self) -> E
where E: Copy + One<Output = E> + FloatConst + Add<Output = E> + Mul,

Gets this sphere’s surface area.

pub fn volume(self) -> E
where E: Copy + One<Output = E> + FloatConst + Add<Output = E> + Mul + Div<Output = E>,

Gets this sphere’s volume.

Source

impl<P, E> Sphere<P, E>

pub fn new(center: Vec3<P>, radius: E) -> Sphere<P, E>

Creates a new Sphere from center and radius.

pub fn unit(center: Vec3<P>) -> Sphere<P, E>
where E: One,

Creates a new Sphere from center and a radius equal to one.

pub fn point(center: Vec3<P>) -> Sphere<P, E>
where E: Zero,

Creates a new Sphere from center and a radius equal to zero.

pub fn diameter(self) -> E
where E: Copy + Add<Output = E>,

Gets the value of twice the radius.

pub fn rect3(self) -> Rect3<P, E>
where P: Sub<Output = P> + From<E> + Copy, E: Copy + Add<Output = E>,

Gets the bounding rectangle for this shape.

Source

impl<T> Sphere<T, T>
where T: Add<Output = T> + Sub<Output = T> + Copy,

pub fn aabb(self) -> Aabb<T>

Gets this shape’s bounds.

Source

impl<T> Sphere<T, T>
where T: Real<Output = T> + Add,

pub fn contains_point(self, p: Vec3<T>) -> bool
where T: PartialOrd,

Does this shape contain the given point ?

pub fn collides_with_sphere(self, other: Sphere<T, T>) -> bool
where T: PartialOrd,

Does this shape collide with another ?

pub fn collision_vector_with_sphere(self, other: Sphere<T, T>) -> Vec3<T>

Gets a vector that tells how much this shape penetrates another.