TheAcceleratorKey

Struct TheAcceleratorKey 

pub struct TheAcceleratorKey { /* private fields */ }

Implementations

Source

impl TheAcceleratorKey

pub const SHIFT: TheAcceleratorKey

Shift Key

pub const CTRL: TheAcceleratorKey

Ctrl Key / Control on Mac

pub const ALT: TheAcceleratorKey

Alt Key / Option on Mac

pub const CMD: TheAcceleratorKey

Cmd on Mac

pub const CTRLCMD: TheAcceleratorKey

CtrlAndCmd

pub const ALL: TheAcceleratorKey

The combination of A, B, and C.

pub const fn empty() -> TheAcceleratorKey

Returns an empty set of flags.

pub const fn all() -> TheAcceleratorKey

Returns the set containing all flags.

pub const fn bits(&self) -> u32

Returns the raw value of the flags currently stored.

pub fn from_bits(bits: u32) -> Option<TheAcceleratorKey>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub const fn from_bits_truncate(bits: u32) -> TheAcceleratorKey

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub const fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

pub const fn is_all(&self) -> bool

Returns true if all flags are currently set.

pub const fn intersects(&self, other: TheAcceleratorKey) -> bool

Returns true if there are flags common to both self and other.

pub const fn contains(&self, other: TheAcceleratorKey) -> bool

Returns true all of the flags in other are contained within self.

pub fn insert(&mut self, other: TheAcceleratorKey)

Inserts the specified flags in-place.

pub fn remove(&mut self, other: TheAcceleratorKey)

Removes the specified flags in-place.

pub fn toggle(&mut self, other: TheAcceleratorKey)

Toggles the specified flags in-place.

pub fn set(&mut self, other: TheAcceleratorKey, value: bool)

Inserts or removes the specified flags depending on the passed value.