TheCanvas

Struct TheCanvas 

pub struct TheCanvas {
Show 13 fields pub uuid: Uuid, pub limiter: TheSizeLimiter, pub offset: Vec2<i32>, pub dim: TheDim, pub root: bool, pub top_is_expanding: bool, pub bottom_is_expanding: bool, pub buffer: TheRGBABuffer, pub left: Option<Box<TheCanvas>>, pub top: Option<Box<TheCanvas>>, pub right: Option<Box<TheCanvas>>, pub bottom: Option<Box<TheCanvas>>, pub center: Option<Box<TheCanvas>>, /* private fields */
}

Fields

uuid: Uuidlimiter: TheSizeLimiteroffset: Vec2<i32>

The relative offset to the parent canvas

dim: TheDimroot: booltop_is_expanding: boolbottom_is_expanding: boolbuffer: TheRGBABufferleft: Option<Box<TheCanvas>>top: Option<Box<TheCanvas>>right: Option<Box<TheCanvas>>bottom: Option<Box<TheCanvas>>center: Option<Box<TheCanvas>>

Implementations

Source

impl TheCanvas

TheCanvas divides a screen dimension into 4 possible sub-spaces for its border while containing a set of widgets for its center.

pub fn new() -> TheCanvas

pub fn set_dim(&mut self, dim: TheDim, ctx: &mut TheContext)

Set the dimension of the canvas

pub fn limiter_mut(&mut self) -> &mut TheSizeLimiter

Returns a mutable reference to the limiter of the widget.

pub fn set_widget<T>(&mut self, widget: T)
where T: TheWidget + 'static,

Sets the widget.

pub fn set_layout<T>(&mut self, layout: T)
where T: TheLayout + 'static,

Sets the layout.

pub fn set_left(&mut self, canvas: TheCanvas)

Sets the canvas to the left of this canvas.

pub fn set_top(&mut self, canvas: TheCanvas)

Sets the canvas to the top of this canvas.

pub fn set_right(&mut self, canvas: TheCanvas)

Sets the canvas to the right of this canvas.

pub fn set_bottom(&mut self, canvas: TheCanvas)

Sets the canvas to the bottom of this canvas.

pub fn set_center(&mut self, canvas: TheCanvas)

Sets the canvas in the center of this canvas.

pub fn resize(&mut self, width: i32, height: i32, ctx: &mut TheContext) -> bool

Resize the canvas if needed

pub fn buffer(&mut self) -> &TheRGBABuffer

Returns a reference to the underlying buffer

pub fn get_canvas(&mut self, uuid: Uuid) -> Option<&mut TheCanvas>

Returns the canvas of the given id

pub fn get_widget( &mut self, name: Option<&String>, uuid: Option<&Uuid>, ) -> Option<&mut Box<dyn TheWidget>>

Returns the widget of the given id

pub fn get_layout( &mut self, name: Option<&String>, uuid: Option<&Uuid>, ) -> Option<&mut Box<dyn TheLayout>>

Returns the layout of the given id

pub fn get_layout_at_coord(&mut self, coord: Vec2<i32>) -> Option<TheId>

Returns the layout id at the given screen coordinate (if any)

pub fn get_widget_at_coord( &mut self, coord: Vec2<i32>, ) -> Option<&mut Box<dyn TheWidget>>

Returns the widget at the given screen coordinate (if any)

pub fn layout(&mut self, width: i32, height: i32, ctx: &mut TheContext)

Layout the canvas according to its dimensions.

pub fn draw(&mut self, style: &mut Box<dyn TheStyle>, ctx: &mut TheContext)

Draw the canvas

pub fn draw_overlay( &mut self, style: &mut Box<dyn TheStyle>, ctx: &mut TheContext, )

pub fn needs_redraw(&mut self) -> bool

Returns true if any widget or layout attached to this canvas (or its children) needs a redraw.