pub struct TheCollection {
pub name: String,
pub keys: IndexMap<String, TheValue>,
}Expand description
Represents a collection of TheValues.
Fields
name: Stringkeys: IndexMap<String, TheValue>Implementations
Sourceimpl TheCollection
impl TheCollection
pub fn named(name: String) -> TheCollection
pub fn new() -> TheCollection
Sourcepub fn get_default(&self, key: &str, default: TheValue) -> TheValue
pub fn get_default(&self, key: &str, default: TheValue) -> TheValue
Returns the given key, if not found return the default.
Sourcepub fn get_f32_default(&self, key: &str, default: f32) -> f32
pub fn get_f32_default(&self, key: &str, default: f32) -> f32
Get an f32 value, if not found return the default.
Sourcepub fn get_float3_default(&self, key: &str, default: Vec3<f32>) -> Vec3<f32>
pub fn get_float3_default(&self, key: &str, default: Vec3<f32>) -> Vec3<f32>
Get an Float3 value, if not found return the default.
Sourcepub fn get_i32_default(&self, key: &str, default: i32) -> i32
pub fn get_i32_default(&self, key: &str, default: i32) -> i32
Get an i32 value, if not found return the default.
Sourcepub fn get_bool_default(&self, key: &str, default: bool) -> bool
pub fn get_bool_default(&self, key: &str, default: bool) -> bool
Get a bool value, if not found return the default.
Sourcepub fn contains_key(&self, key: &str) -> bool
pub fn contains_key(&self, key: &str) -> bool
Checks if the collection contains the given key.