pub struct TheColor {
pub r: f32,
pub g: f32,
pub b: f32,
pub a: f32,
pub name: String,
}Expand description
Holds a normalized color value and offers several import and export methods.
Fields
r: f32g: f32b: f32a: f32name: StringImplementations
Sourceimpl TheColor
impl TheColor
Sourcepub fn from_u8_array(color: [u8; 4]) -> TheColor
pub fn from_u8_array(color: [u8; 4]) -> TheColor
Creates a color from 4 u8 values.
Sourcepub fn from_u8_array_3(color: [u8; 3]) -> TheColor
pub fn from_u8_array_3(color: [u8; 3]) -> TheColor
Creates a color from 3 u8 values.
Sourcepub fn from_vec4f(color: Vec4<f32>) -> TheColor
pub fn from_vec4f(color: Vec4<f32>) -> TheColor
Creates a color from an vec4.
Sourcepub fn transparent() -> TheColor
pub fn transparent() -> TheColor
Creates a transparent color.
Sourcepub fn to_array_3(&self) -> [f32; 3]
pub fn to_array_3(&self) -> [f32; 3]
Creates an [f32;3] array
Sourcepub fn to_u8_array_3(&self) -> [u8; 3]
pub fn to_u8_array_3(&self) -> [u8; 3]
Creates an [u8;3] array
Sourcepub fn to_u8_array(&self) -> [u8; 4]
pub fn to_u8_array(&self) -> [u8; 4]
Creates an [u8;4] array
pub fn as_srgba(&self) -> TheColor
Sourcepub fn lighten_darken(&self, amount: f32) -> TheColor
pub fn lighten_darken(&self, amount: f32) -> TheColor
Lights or darken the color by the given amount.