pub struct TheDim {
pub x: i32,
pub y: i32,
pub width: i32,
pub height: i32,
pub buffer_x: i32,
pub buffer_y: i32,
}Fields
x: i32The x offset in screen coordinates
y: i32The y offset in screen coordinates
width: i32height: i32buffer_x: i32The x offset relative to the canvas buffer
buffer_y: i32The y offset relative to the canvas buffer
Implementations
Sourceimpl TheDim
impl TheDim
pub fn zero() -> TheDim
pub fn new(x: i32, y: i32, width: i32, height: i32) -> TheDim
pub fn rect(x: i32, y: i32, width: i32, height: i32) -> TheDim
pub fn sized(width: i32, height: i32) -> TheDim
Sourcepub fn set_buffer_offset(&mut self, buffer_x: i32, buffer_y: i32)
pub fn set_buffer_offset(&mut self, buffer_x: i32, buffer_y: i32)
Sets the offset relative to the canvas buffer.
pub fn screen_coord(&self) -> Vec2<i32>
Sourcepub fn contains(&self, coord: Vec2<i32>) -> bool
pub fn contains(&self, coord: Vec2<i32>) -> bool
Checks if the given coordinate is inside the dimension.
Sourcepub fn to_local(&self, coord: Vec2<i32>) -> Vec2<i32>
pub fn to_local(&self, coord: Vec2<i32>) -> Vec2<i32>
Returns the given screen coordinate as a local coordinate.
Sourcepub fn to_buffer_utuple(&self) -> (usize, usize, usize, usize)
pub fn to_buffer_utuple(&self) -> (usize, usize, usize, usize)
Returns the dimension as an usize tuple relative to the buffer origin (used by the drawing routines)
Sourcepub fn to_buffer_shrunk_utuple(
&self,
shrinker: &TheDimShrinker,
) -> (usize, usize, usize, usize)
pub fn to_buffer_shrunk_utuple( &self, shrinker: &TheDimShrinker, ) -> (usize, usize, usize, usize)
Returns the dimension as an usize tuple relative to the buffer origin (used by the drawing routines)