TheDraw2D

Struct TheDraw2D 

pub struct TheDraw2D {
    pub mask: Option<Vec<f32>>,
    pub mask_size: (usize, usize),
    pub fonts: Vec<Font>,
    pub code_fonts: Vec<Font>,
}

Fields

mask: Option<Vec<f32>>mask_size: (usize, usize)fonts: Vec<Font>code_fonts: Vec<Font>

Implementations

Source

impl TheDraw2D

pub fn new() -> TheDraw2D

pub fn blend_mask( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, mask_frame: &[u8], mask_size: &(usize, usize), color: &[u8; 4], )

Draws the mask

pub fn rect( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, color: &[u8; 4], )

Draws the given rectangle

pub fn rect_safe( &self, frame: &mut [u8], rect: &(isize, isize, usize, usize), stride: usize, color: &[u8; 4], safe_rect: &(usize, usize, usize, usize), )

Draws the given rectangle and checks the frame boundaries.

pub fn blend_rect( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, color: &[u8; 4], )

Blend the given rectangle

pub fn rect_outline( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, color: &[u8; 4], )

Draws the outline of a given rectangle

pub fn rect_outline_border( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, color: &[u8; 4], border: usize, )

Draws the outline of a given rectangle

pub fn rect_outline_border_open( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, color: &[u8; 4], border: usize, )

Draws the outline of a given rectangle with the right open

pub fn rect_outline_border_safe( &self, frame: &mut [u8], rect: &(isize, isize, usize, usize), stride: usize, color: &[u8; 4], border: isize, safe_rect: &(usize, usize, usize, usize), )

Draws the outline of a given rectangle

pub fn circle( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, color: &[u8; 4], radius: f32, )

Draws a circle

pub fn circle_with_border( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, color: &[u8; 4], radius: f32, border_color: &[u8; 4], border_size: f32, )

Draws a circle with a border of a given size

pub fn rounded_rect( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, color: &[u8; 4], rounding: &(f32, f32, f32, f32), )

Draws a rounded rect

pub fn rounded_rect_with_border( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, color: &[u8; 4], rounding: &(f32, f32, f32, f32), border_color: &[u8; 4], border_size: f32, )

Draws a rounded rect with a border

pub fn hexagon_with_border( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, color: &[u8; 4], border_color: &[u8; 4], border_size: f32, )

Draws a hexagon with a border

pub fn rhombus_with_border( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, color: &[u8; 4], border_color: &[u8; 4], border_size: f32, )

Draws a rhombus rect with a border

pub fn square_pattern( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, color: &[u8; 4], line_color: &[u8; 4], pattern_size: usize, )

Draws a square pattern

pub fn wavy_line( &self, frame: &mut [u8], left: i32, base: i32, length: usize, amplitude: f32, _period: f32, stride: usize, color: &[u8; 4], )

pub fn text_rect( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, text: &str, settings: TheFontSettings, color: &[u8; 4], background: &[u8; 4], halign: TheHorizontalAlign, valign: TheVerticalAlign, )

Draws a text aligned inside a rect

pub fn text_rect_clip( &self, frame: &mut [u8], top_left: &Vec2<i32>, clip_rect: &(usize, usize, usize, usize), stride: usize, text: &str, settings: TheFontSettings, color: &[u8; 4], background: &[u8; 4], halign: TheHorizontalAlign, valign: TheVerticalAlign, )

Draws a text aligned inside a rect

pub fn text_rect_blend( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, text: &str, settings: TheFontSettings, color: &[u8; 4], halign: TheHorizontalAlign, valign: TheVerticalAlign, )

Blends a text aligned inside a rect and blends it with the existing background

pub fn text_rect_blend_clip( &self, frame: &mut [u8], top_left: &Vec2<i32>, clip_rect: &(usize, usize, usize, usize), stride: usize, text: &str, settings: TheFontSettings, color: &[u8; 4], halign: TheHorizontalAlign, valign: TheVerticalAlign, )

Blends a text aligned inside a rect and blends it with the existing background

pub fn text( &self, frame: &mut [u8], pos: &(usize, usize), stride: usize, text: &str, settings: TheFontSettings, color: &[u8; 4], background: &[u8; 4], )

Draws the given text

pub fn text_blend( &self, frame: &mut [u8], pos: &(usize, usize), stride: usize, text: &str, settings: TheFontSettings, color: &[u8; 4], )

Draws the given text

pub fn get_text_layout( &self, text: &str, font_settings: &TheFontSettings, layout_settings: LayoutSettings, ) -> Layout

Returns the layout of the given text

pub fn get_text_size( &self, text: &str, settings: &TheFontSettings, ) -> (usize, usize)

Returns the size of the given text

pub fn copy_slice( &self, dest: &mut [u8], source: &[u8], rect: &(usize, usize, usize, usize), dest_stride: usize, )

Copies rect from the source frame into the dest frame

pub fn blend_slice( &self, dest: &mut [u8], source: &[u8], rect: &(usize, usize, usize, usize), dest_stride: usize, )

Blends rect from the source frame into the dest frame

pub fn blend_slice_alpha( &self, dest: &mut [u8], source: &[u8], rect: &(usize, usize, usize, usize), dest_stride: usize, alpha: f32, )

Blends rect from the source frame into the dest frame

pub fn blend_slice_f32( &self, dest: &mut [u8], source: &[f32], rect: &(usize, usize, usize, usize), dest_stride: usize, )

Blends rect from the source frame into the dest frame

pub fn blend_slice_offset( &self, dest: &mut [u8], source: &[u8], rect: &(usize, usize, usize, usize), offset: usize, dest_stride: usize, )

Blends rect from the source frame into the dest frame with a vertical source offset (used by scrolling containers)

pub fn blend_slice_safe( &self, dest: &mut [u8], source: &[u8], rect: &(isize, isize, usize, usize), dest_stride: usize, safe_rect: &(usize, usize, usize, usize), )

Blends rect from the source frame into the dest frame and honors the safe rect

pub fn scale_chunk( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, source_frame: &[u8], source_size: &(usize, usize), blend_factor: f32, )

Scale a chunk to the destination size

pub fn blend_scale_chunk( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, source_frame: &[u8], source_size: &(usize, usize), )

Scale a chunk to the destination size

pub fn blend_scale_chunk_alpha( &self, frame: &mut [u8], rect: &(usize, usize, usize, usize), stride: usize, source_frame: &[u8], source_size: &(usize, usize), alpha: f32, )

Scale a chunk to the destination size with a global alpha

pub fn blend_scale_chunk_linear( &self, dest: &mut [u8], dest_rect: &(usize, usize, usize, usize), dest_stride: usize, source: &[u8], source_size: &(usize, usize), )

Scale a chunk to the destination size with linear interpolation and blend onto destination

pub fn add_font_data<Data>(&mut self, data: Data)
where Data: Deref<Target = [u8]>,

pub fn add_code_font_data<Data>(&mut self, data: Data)
where Data: Deref<Target = [u8]>,

pub fn _smoothstep(&self, e0: f32, e1: f32, x: f32) -> f32

Smoothstep for f32

pub fn mix_color(&self, a: &[u8; 4], b: &[u8; 4], v: f32) -> [u8; 4]

Mixes two colors based on v

pub fn length(&self, v: (f32, f32)) -> f32