pub struct TheNodeCanvas {
pub nodes: Vec<TheNode>,
pub node_width: i32,
pub connections: Vec<(u16, u8, u16, u8)>,
pub offset: Vec2<i32>,
pub selected_node: Option<usize>,
pub zoom: f32,
pub categories: HashMap<String, TheColor, FxBuildHasher>,
}Fields
nodes: Vec<TheNode>The nodes in the canvas, identified by their index.
node_width: i32The width of a node.
connections: Vec<(u16, u8, u16, u8)>The node connections: Source node index, source terminal, dest node index, dest terminal
offset: Vec2<i32>The scroll offset.
selected_node: Option<usize>The currently selected node.
zoom: f32The zoom level.
categories: HashMap<String, TheColor, FxBuildHasher>The node categories
Implementations
Sourceimpl TheNodeCanvas
impl TheNodeCanvas
pub fn new() -> TheNodeCanvas