pub struct TheNodeUI { /* private fields */ }Expand description
A container for UI items. Supports adding them to a text layout or handling events for updating the values.
Implementations
Sourceimpl TheNodeUI
impl TheNodeUI
pub fn new() -> TheNodeUI
Sourcepub fn add_item(&mut self, item: TheNodeUIItem) -> Option<TheNodeUIItem>
pub fn add_item(&mut self, item: TheNodeUIItem) -> Option<TheNodeUIItem>
Adds a new item to the UI
Sourcepub fn remove_item(&mut self, id: &str) -> Option<TheNodeUIItem>
pub fn remove_item(&mut self, id: &str) -> Option<TheNodeUIItem>
Removes an item by its ID
Sourcepub fn get_item(&self, id: &str) -> Option<&TheNodeUIItem>
pub fn get_item(&self, id: &str) -> Option<&TheNodeUIItem>
Retrieves a reference to an item by its ID
Sourcepub fn get_item_mut(&mut self, id: &str) -> Option<&mut TheNodeUIItem>
pub fn get_item_mut(&mut self, id: &str) -> Option<&mut TheNodeUIItem>
Retrieves a mutable reference to an item by its ID
Sourcepub fn list_items(&self) -> impl Iterator<Item = (&String, &TheNodeUIItem)>
pub fn list_items(&self) -> impl Iterator<Item = (&String, &TheNodeUIItem)>
Lists all items in the UI
Sourcepub fn get_text_value(&self, id: &str) -> Option<String>
pub fn get_text_value(&self, id: &str) -> Option<String>
Get a text value.
Sourcepub fn get_bool_value(&self, id: &str) -> Option<bool>
pub fn get_bool_value(&self, id: &str) -> Option<bool>
Get a bool value.
Sourcepub fn get_tile_id(&self, id: &str, index: usize) -> Option<Uuid>
pub fn get_tile_id(&self, id: &str, index: usize) -> Option<Uuid>
Get a tile id for the given index
Sourcepub fn get_i32_value(&self, id: &str) -> Option<i32>
pub fn get_i32_value(&self, id: &str) -> Option<i32>
Get an i32 value.
Sourcepub fn get_f32_value(&self, id: &str) -> Option<f32>
pub fn get_f32_value(&self, id: &str) -> Option<f32>
Get an f32 value.
Sourcepub fn set_bool_value(&mut self, id: &str, val: bool)
pub fn set_bool_value(&mut self, id: &str, val: bool)
Set a bool value.
Sourcepub fn set_f32_value(&mut self, id: &str, val: f32)
pub fn set_f32_value(&mut self, id: &str, val: f32)
Set an f32 value.
Sourcepub fn set_i32_value(&mut self, id: &str, val: i32)
pub fn set_i32_value(&mut self, id: &str, val: i32)
Set an f32 value.
Sourcepub fn set_text_value(&mut self, id: &str, val: String)
pub fn set_text_value(&mut self, id: &str, val: String)
Set a text value.
Sourcepub fn apply_to_tree_node(&self, node: &mut TheTreeNode)
pub fn apply_to_tree_node(&self, node: &mut TheTreeNode)
Add the items to the given text layout.
Sourcepub fn apply_to_text_layout(&self, layout: &mut dyn TheTextLayoutTrait)
pub fn apply_to_text_layout(&self, layout: &mut dyn TheTextLayoutTrait)
Add the items to the given text layout.
Sourcepub fn handle_event(&mut self, event: &TheEvent) -> bool
pub fn handle_event(&mut self, event: &TheEvent) -> bool
Handle an event and update the item values if necessary