pub struct TheRGBABuffer { /* private fields */ }Implementations
Sourceimpl TheRGBABuffer
TheRGBABuffer contains the pixel buffer for a canvas or icon.
impl TheRGBABuffer
TheRGBABuffer contains the pixel buffer for a canvas or icon.
Sourcepub fn empty() -> TheRGBABuffer
pub fn empty() -> TheRGBABuffer
Create an empty buffer.
Sourcepub fn new(dim: TheDim) -> TheRGBABuffer
pub fn new(dim: TheDim) -> TheRGBABuffer
Creates a buffer of the given dimension.
Sourcepub fn from(buffer: Vec<u8>, width: u32, height: u32) -> TheRGBABuffer
pub fn from(buffer: Vec<u8>, width: u32, height: u32) -> TheRGBABuffer
Creates a buffer from existing data.
Sourcepub fn pixels_mut(&mut self) -> &mut [u8] ⓘ
pub fn pixels_mut(&mut self) -> &mut [u8] ⓘ
Gets a mutable slice of the buffer.
Sourcepub fn extract(&self, dim: &TheDim) -> TheRGBABuffer
pub fn extract(&self, dim: &TheDim) -> TheRGBABuffer
Extracts a sub-buffer of given dimensions from the current buffer.
Sourcepub fn copy_into(&mut self, x: i32, y: i32, other: &TheRGBABuffer)
pub fn copy_into(&mut self, x: i32, y: i32, other: &TheRGBABuffer)
Copy the other buffer into this buffer at the given coordinates.
Sourcepub fn copy_into_par(&mut self, x: i32, y: i32, other: &TheRGBABuffer)
pub fn copy_into_par(&mut self, x: i32, y: i32, other: &TheRGBABuffer)
Parallel version of copy_into using Rayon. Has identical clipping/safety behavior.
Enabled when the rayon feature is on. When the feature is off, it falls back to the serial version.
Sourcepub fn blend_into(&mut self, x: i32, y: i32, other: &TheRGBABuffer)
pub fn blend_into(&mut self, x: i32, y: i32, other: &TheRGBABuffer)
Blend the other buffer into this buffer at the given coordinates (single-threaded reference path).
Sourcepub fn blend_into_par(&mut self, x: i32, y: i32, other: &TheRGBABuffer)
pub fn blend_into_par(&mut self, x: i32, y: i32, other: &TheRGBABuffer)
Blend the other buffer into this buffer at the given coordinates (adaptive parallel version). Falls back to the single-threaded path for small regions to avoid overhead.
Sourcepub fn copy_horizontal_range_into(
&mut self,
x: i32,
y: i32,
other: &TheRGBABuffer,
range: Range<i32>,
)
pub fn copy_horizontal_range_into( &mut self, x: i32, y: i32, other: &TheRGBABuffer, range: Range<i32>, )
Copy the horizontal range of the other buffer into this buffer at the given coordinates.
Sourcepub fn copy_vertical_range_into(
&mut self,
x: i32,
y: i32,
other: &TheRGBABuffer,
range: Range<i32>,
)
pub fn copy_vertical_range_into( &mut self, x: i32, y: i32, other: &TheRGBABuffer, range: Range<i32>, )
Copy the vertical range of the other buffer into this buffer at the given coordinates.
Sourcepub fn scaled(&self, new_width: i32, new_height: i32) -> TheRGBABuffer
pub fn scaled(&self, new_width: i32, new_height: i32) -> TheRGBABuffer
Creates a scaled version of the buffer.
Sourcepub fn scaled_into(&self, into: &mut TheRGBABuffer)
pub fn scaled_into(&self, into: &mut TheRGBABuffer)
Creates a scaled version of the buffer by writing into the other buffer.
Sourcepub fn scaled_into_linear(&self, into: &mut TheRGBABuffer)
pub fn scaled_into_linear(&self, into: &mut TheRGBABuffer)
Creates a scaled version of the buffer by writing into the other buffer.
Sourcepub fn scaled_into_using_dim(&self, into: &mut TheRGBABuffer, dim: &TheDim)
pub fn scaled_into_using_dim(&self, into: &mut TheRGBABuffer, dim: &TheDim)
Creates a scaled version of the buffer by writing into the other buffer while respecting the dimensions.
Sourcepub fn extract_region(&self, region: &TheRGBARegion) -> TheRGBABuffer
pub fn extract_region(&self, region: &TheRGBARegion) -> TheRGBABuffer
Extracts a region from the buffer.
Sourcepub fn extract_sequence(
&self,
sequence: &TheRGBARegionSequence,
) -> Vec<TheRGBABuffer>
pub fn extract_sequence( &self, sequence: &TheRGBARegionSequence, ) -> Vec<TheRGBABuffer>
Extracts the regions of the sequence from the buffer.
Sourcepub fn at_f_vec4f(&self, uv: Vec2<f32>) -> Option<Vec4<f32>>
pub fn at_f_vec4f(&self, uv: Vec2<f32>) -> Option<Vec4<f32>>
Returns the pixel at the given UV coordinate as [f32;4]
Sourcepub fn at_f(&self, uv: Vec2<f32>) -> Option<[u8; 4]>
pub fn at_f(&self, uv: Vec2<f32>) -> Option<[u8; 4]>
Returns the pixel at the given UV coordinate.
Sourcepub fn at(&self, position: Vec2<i32>) -> Option<[u8; 4]>
pub fn at(&self, position: Vec2<i32>) -> Option<[u8; 4]>
Returns the pixel at the given position.
pub fn at_vec4(&self, position: Vec2<i32>) -> Option<Vec4<f32>>
Sourcepub fn multiply_by_pixel(&mut self, add: [u8; 4], pixel: [u8; 4])
pub fn multiply_by_pixel(&mut self, add: [u8; 4], pixel: [u8; 4])
Multiplies every pixel in the buffer by the given RGBA pixel (component-wise, 0-255 space).
Sourcepub fn draw_line(&mut self, x0: i32, y0: i32, x1: i32, y1: i32, color: [u8; 4])
pub fn draw_line(&mut self, x0: i32, y0: i32, x1: i32, y1: i32, color: [u8; 4])
Draws a line from (x0, y0) to (x1, y1) with the given color.
Sourcepub fn draw_horizontal_line(&mut self, x0: i32, x1: i32, y: i32, color: [u8; 4])
pub fn draw_horizontal_line(&mut self, x0: i32, x1: i32, y: i32, color: [u8; 4])
Draws a horizontal line from (x0, y) to (x1, y) with the given color.
Sourcepub fn draw_vertical_line(&mut self, x: i32, y0: i32, y1: i32, color: [u8; 4])
pub fn draw_vertical_line(&mut self, x: i32, y0: i32, y1: i32, color: [u8; 4])
Draws a vertical line from (x, y0) to (x, y1) with the given color.
Sourcepub fn draw_rect_outline(&mut self, rect: &TheDim, color: &[u8; 4])
pub fn draw_rect_outline(&mut self, rect: &TheDim, color: &[u8; 4])
Draws the outline of a given rectangle
Sourcepub fn draw_rounded_rect(
&mut self,
dim: &TheDim,
color: &[u8; 4],
rounding: &(f32, f32, f32, f32),
border_size: f32,
border_color: &[u8; 4],
)
pub fn draw_rounded_rect( &mut self, dim: &TheDim, color: &[u8; 4], rounding: &(f32, f32, f32, f32), border_size: f32, border_color: &[u8; 4], )
Draws a rounded rect with a border
Sourcepub fn draw_disc(
&mut self,
dim: &TheDim,
color: &[u8; 4],
border_size: f32,
border_color: &[u8; 4],
)
pub fn draw_disc( &mut self, dim: &TheDim, color: &[u8; 4], border_size: f32, border_color: &[u8; 4], )
Draws a rounded rect with a border
Sourcepub fn draw_text(
&mut self,
position: Vec2<i32>,
font: &Font,
text: &str,
size: f32,
color: [u8; 4],
halign: TheHorizontalAlign,
valign: TheVerticalAlign,
)
pub fn draw_text( &mut self, position: Vec2<i32>, font: &Font, text: &str, size: f32, color: [u8; 4], halign: TheHorizontalAlign, valign: TheVerticalAlign, )
Render an aligned text in the buffer.
Sourcepub fn pixel_index(&self, x: i32, y: i32) -> Option<usize>
pub fn pixel_index(&self, x: i32, y: i32) -> Option<usize>
Helper method to calculate the buffer index for a pixel at (x, y).
Sourcepub fn set_pixel(&mut self, x: i32, y: i32, color: &[u8; 4])
pub fn set_pixel(&mut self, x: i32, y: i32, color: &[u8; 4])
Sets the color of a pixel at (x, y).
Sourcepub fn to_png(&self) -> Result<Vec<u8>, EncodingError>
pub fn to_png(&self) -> Result<Vec<u8>, EncodingError>
Convert the buffer to an RGBA PNG image.
Sourcepub fn render_hsl_hue_waveform(&mut self)
pub fn render_hsl_hue_waveform(&mut self)
Draw an hsl hue waveform used by color pickers.