pub struct TheRGBBuffer { /* private fields */ }Implementations
Sourceimpl TheRGBBuffer
TheRGBABuffer contains the pixel buffer for a canvas or icon.
impl TheRGBBuffer
TheRGBABuffer contains the pixel buffer for a canvas or icon.
Sourcepub fn empty() -> TheRGBBuffer
pub fn empty() -> TheRGBBuffer
Create an empty buffer.
Sourcepub fn new(dim: TheDim) -> TheRGBBuffer
pub fn new(dim: TheDim) -> TheRGBBuffer
Creates a buffer of the given dimension.
Sourcepub fn from(buffer: Vec<u8>, width: u32, height: u32) -> TheRGBBuffer
pub fn from(buffer: Vec<u8>, width: u32, height: u32) -> TheRGBBuffer
Creates a buffer from existing data.
Sourcepub fn pixels_mut(&mut self) -> &mut [u8] ⓘ
pub fn pixels_mut(&mut self) -> &mut [u8] ⓘ
Gets a mutable slice of the buffer.
Sourcepub fn copy_into(&mut self, x: i32, y: i32, other: &TheRGBBuffer)
pub fn copy_into(&mut self, x: i32, y: i32, other: &TheRGBBuffer)
Copy the other buffer into this buffer at the given coordinates.
Sourcepub fn scaled(&self, new_width: i32, new_height: i32) -> TheRGBBuffer
pub fn scaled(&self, new_width: i32, new_height: i32) -> TheRGBBuffer
Creates a scaled version of the buffer.
Sourcepub fn at_f_vec3f(&self, uv: Vec2<f32>) -> Option<Vec3<f32>>
pub fn at_f_vec3f(&self, uv: Vec2<f32>) -> Option<Vec3<f32>>
Returns the pixel at the given UV coordinate as [f32;3]
Sourcepub fn at_f(&self, uv: Vec2<f32>) -> Option<[u8; 3]>
pub fn at_f(&self, uv: Vec2<f32>) -> Option<[u8; 3]>
Returns the pixel at the given UV coordinate.
Sourcepub fn at(&self, position: Vec2<i32>) -> Option<[u8; 3]>
pub fn at(&self, position: Vec2<i32>) -> Option<[u8; 3]>
Returns the pixel at the given position.
pub fn at_vec3(&self, position: Vec2<i32>) -> Option<Vec3<f32>>
Sourcepub fn pixel_index(&self, x: i32, y: i32) -> Option<usize>
pub fn pixel_index(&self, x: i32, y: i32) -> Option<usize>
Helper method to calculate the buffer index for a pixel at (x, y).
Sourcepub fn set_pixel(&mut self, x: i32, y: i32, color: &[u8; 3])
pub fn set_pixel(&mut self, x: i32, y: i32, color: &[u8; 3])
Sets the color of a pixel at (x, y).
Sourcepub fn set_pixel_vec3f(&mut self, x: i32, y: i32, color: &Vec3<f32>)
pub fn set_pixel_vec3f(&mut self, x: i32, y: i32, color: &Vec3<f32>)
Sets the color of a pixel at (x, y).
Sourcepub fn to_png(&self) -> Result<Vec<u8>, EncodingError>
pub fn to_png(&self) -> Result<Vec<u8>, EncodingError>
Convert the buffer to an RGBA PNG image.
Sourcepub fn to_rgba(&self) -> TheRGBABuffer
pub fn to_rgba(&self) -> TheRGBABuffer
Convert the buffer to an TheRGBABuffer.