pub struct TheSectionbar { /* private fields */ }Trait Implementations
Sourceimpl TheWidget for TheSectionbar
impl TheWidget for TheSectionbar
fn new(id: TheId) -> TheSectionbarwhere
TheSectionbar: Sized,
fn id(&self) -> &TheId
Sourcefn dim_mut(&mut self) -> &mut TheDim
fn dim_mut(&mut self) -> &mut TheDim
Returns a mutable reference to the dimensions of the widget.
Sourcefn set_dim(&mut self, dim: TheDim, _ctx: &mut TheContext)
fn set_dim(&mut self, dim: TheDim, _ctx: &mut TheContext)
Set the dimensions of the widget
Sourcefn limiter(&self) -> &TheSizeLimiter
fn limiter(&self) -> &TheSizeLimiter
Returns a reference to the size limiter of the widget.
Sourcefn limiter_mut(&mut self) -> &mut TheSizeLimiter
fn limiter_mut(&mut self) -> &mut TheSizeLimiter
Returns a mutable reference to the limiter of the widget.
Sourcefn needs_redraw(&mut self) -> bool
fn needs_redraw(&mut self) -> bool
If this function returns true it indicates that the widget needs a redraw.
Sourcefn draw(
&mut self,
buffer: &mut TheRGBABuffer,
style: &mut Box<dyn TheStyle>,
ctx: &mut TheContext,
)
fn draw( &mut self, buffer: &mut TheRGBABuffer, style: &mut Box<dyn TheStyle>, ctx: &mut TheContext, )
Draw the widget in the given style
Sourcefn calculate_size(&mut self, ctx: &mut TheContext)
fn calculate_size(&mut self, ctx: &mut TheContext)
Called during layouts to give Widgets a chance to dynamically change size (for example for when a widgets text changes). The function is supposed to adjust its limiter.
Sourcefn state(&self) -> TheWidgetState
fn state(&self) -> TheWidgetState
Returns the current state of the widget.
Sourcefn set_state(&mut self, state: TheWidgetState)
fn set_state(&mut self, state: TheWidgetState)
Set the widget state.
Sourcefn set_embedded(&mut self, embedded: bool)
fn set_embedded(&mut self, embedded: bool)
Set the embedded state.
Sourcefn set_parent_id(&mut self, parent_id: TheId)
fn set_parent_id(&mut self, parent_id: TheId)
Set the parent id for embedded widgets.
Sourcefn has_parent_focus(&self, ctx: &TheContext) -> bool
fn has_parent_focus(&self, ctx: &TheContext) -> bool
Check if the parent widget has focus (for embedded widgets).
Sourcefn cursor_icon(&self) -> Option<TheCursorIcon>
fn cursor_icon(&self) -> Option<TheCursorIcon>
Get the cursor icon for this widget when hovered.
Sourcefn set_cursor_icon(&mut self, _icon: Option<TheCursorIcon>)
fn set_cursor_icon(&mut self, _icon: Option<TheCursorIcon>)
Set the cursor icon for this widget.
Sourcefn status_text(&self) -> Option<String>
fn status_text(&self) -> Option<String>
Retrieves the status text for the widget.
Sourcefn set_status_text(&mut self, text: &str)
fn set_status_text(&mut self, text: &str)
Sets the status text for the widget.
Sourcefn draw_overlay(
&mut self,
style: &mut Box<dyn TheStyle>,
ctx: &mut TheContext,
) -> TheRGBABuffer
fn draw_overlay( &mut self, style: &mut Box<dyn TheStyle>, ctx: &mut TheContext, ) -> TheRGBABuffer
Draw the widget in the given style
Sourcefn supports_hover(&mut self) -> bool
fn supports_hover(&mut self) -> bool
Widgets who support hover return true
Sourcefn supports_text_input(&self) -> bool
fn supports_text_input(&self) -> bool
Widgets who support text input return true
Sourcefn supports_clipboard(&mut self) -> bool
fn supports_clipboard(&mut self) -> bool
Widgets who support clipboard operations return true
Sourcefn supports_undo_redo(&mut self) -> bool
fn supports_undo_redo(&mut self) -> bool
Widgets who support internal undo / redo
Sourcefn set_needs_redraw(&mut self, redraw: bool)
fn set_needs_redraw(&mut self, redraw: bool)
Sets the internal redraw flag of the widget to the given value.
Sourcefn set_disabled(&mut self, disabled: bool)
fn set_disabled(&mut self, disabled: bool)
Set the disabled state of the widget
Sourcefn on_event(&mut self, event: &TheEvent, ctx: &mut TheContext) -> bool
fn on_event(&mut self, event: &TheEvent, ctx: &mut TheContext) -> bool
Process an user driven device event, returns true if we need to redraw.
Sets the context menu for the widget.
Sourcefn as_list_item(&mut self) -> Option<&mut dyn TheListItemTrait>
fn as_list_item(&mut self) -> Option<&mut dyn TheListItemTrait>
Attempts to cast to TheListItemTrait. Only valid for TheListItem.
Sourcefn as_tree_item(&mut self) -> Option<&mut dyn TheTreeItemTrait>
fn as_tree_item(&mut self) -> Option<&mut dyn TheTreeItemTrait>
Attempts to cast to TheTreeItemTrait. Only valid for TheListItem.
Sourcefn as_rowlist_item(&mut self) -> Option<&mut dyn TheRowListItemTrait>
fn as_rowlist_item(&mut self) -> Option<&mut dyn TheRowListItemTrait>
Attempts to cast to TheRowListItemTrait. Only valid for TheRowListItem.
Attempts to cast to TheDropdownMenuTrait. Only valid for TheDropdownMenu.
Sourcefn as_horizontal_scrollbar(
&mut self,
) -> Option<&mut dyn TheHorizontalScrollbarTrait>
fn as_horizontal_scrollbar( &mut self, ) -> Option<&mut dyn TheHorizontalScrollbarTrait>
Attempts to cast to TheHorizontalScrollbarTrait. Only valid for TheHorizontalScrollbar.
Sourcefn as_vertical_scrollbar(
&mut self,
) -> Option<&mut dyn TheVerticalScrollbarTrait>
fn as_vertical_scrollbar( &mut self, ) -> Option<&mut dyn TheVerticalScrollbarTrait>
Attempts to cast to TheVerticalScrollbarTrait. Only valid for TheVerticalScrollbar.
Sourcefn as_rgba_view(&mut self) -> Option<&mut dyn TheRGBAViewTrait>
fn as_rgba_view(&mut self) -> Option<&mut dyn TheRGBAViewTrait>
Attempts to cast to TheRGBAView. Only valid for TheRGBAViewTrait.
Sourcefn as_render_view(&mut self) -> Option<&mut dyn TheRenderViewTrait>
fn as_render_view(&mut self) -> Option<&mut dyn TheRenderViewTrait>
Attempts to cast to TheRenderViewTrait. Only valid for TheRenderView.
Sourcefn as_node_canvas_view(&mut self) -> Option<&mut dyn TheNodeCanvasViewTrait>
fn as_node_canvas_view(&mut self) -> Option<&mut dyn TheNodeCanvasViewTrait>
Attempts to cast to TheNodeViewTrait. Only valid for TheNodeView.
Sourcefn as_text(&mut self) -> Option<&mut dyn TheTextTrait>
fn as_text(&mut self) -> Option<&mut dyn TheTextTrait>
Attempts to cast to TheTextTrait. Only valid for TheText.
Sourcefn as_tabbar(&mut self) -> Option<&mut dyn TheTabbarTrait>
fn as_tabbar(&mut self) -> Option<&mut dyn TheTabbarTrait>
Attempts to cast to TheTabbarTrait. Only valid for TheTabbar.
Sourcefn as_text_area_edit(&mut self) -> Option<&mut dyn TheTextAreaEditTrait>
fn as_text_area_edit(&mut self) -> Option<&mut dyn TheTextAreaEditTrait>
Attempts to cast to TheTextAreaEditTrait. Only valid for TheTextAreaEdit.
Sourcefn as_text_line_edit(&mut self) -> Option<&mut dyn TheTextLineEditTrait>
fn as_text_line_edit(&mut self) -> Option<&mut dyn TheTextLineEditTrait>
Attempts to cast to TheTextLineEditTrait. Only valid for TheTextLineEdit.
Sourcefn as_text_view(&mut self) -> Option<&mut dyn TheTextViewTrait>
fn as_text_view(&mut self) -> Option<&mut dyn TheTextViewTrait>
Attempts to cast to TheTextViewTrait. Only valid for TheTextView.
Sourcefn as_markdown_view(&mut self) -> Option<&mut dyn TheMarkdownViewTrait>
fn as_markdown_view(&mut self) -> Option<&mut dyn TheMarkdownViewTrait>
Attempts to cast to TheMarkdownViewTrait. Only valid for TheMarkdownView.
Sourcefn as_icon_view(&mut self) -> Option<&mut dyn TheIconViewTrait>
fn as_icon_view(&mut self) -> Option<&mut dyn TheIconViewTrait>
Attempts to cast to TheIconViewTrait. Only valid for TheIconView.
Attempts to cast to TheGroupButtonTrait. Only valid for TheGroupButton.
Sourcefn as_statusbar(&mut self) -> Option<&mut dyn TheStatusbarTrait>
fn as_statusbar(&mut self) -> Option<&mut dyn TheStatusbarTrait>
Attempts to cast to TheStatusbarTrait. Only valid for TheStatusbar.
Attempts to cast to TheMenubarButtonTrait. Only valid for TheMenubarButton.
Sourcefn as_time_slider(&mut self) -> Option<&mut dyn TheTimeSliderTrait>
fn as_time_slider(&mut self) -> Option<&mut dyn TheTimeSliderTrait>
Attempts to cast to TheTimeSlider. Only valid for TheTimeSliderTrait.
Sourcefn as_palette_picker(&mut self) -> Option<&mut dyn ThePalettePickerTrait>
fn as_palette_picker(&mut self) -> Option<&mut dyn ThePalettePickerTrait>
Attempts to cast to ThePalettePickerTrait. Only valid for ThePalettePicker.
Attempts to cast to TheMenuTrait. Only valid for TheMenu.
Sourcefn as_tree_icons(&mut self) -> Option<&mut dyn TheTreeIconsTrait>
fn as_tree_icons(&mut self) -> Option<&mut dyn TheTreeIconsTrait>
Attempts to cast to TheTreeIconsTrait. Only valid for TheTreeIcons.
Sourcefn as_tree_text(&mut self) -> Option<&mut dyn TheTreeTextTrait>
fn as_tree_text(&mut self) -> Option<&mut dyn TheTreeTextTrait>
Attempts to cast to TheTreeTextTrait. Only valid for TheTreeText.