pub struct TheTimeline {
pub events: BTreeMap<TheTime, Vec<TheCollection>>,
}Expand description
Represents a collection of TheValues.
Fields
events: BTreeMap<TheTime, Vec<TheCollection>>Implementations
Sourceimpl TheTimeline
impl TheTimeline
pub fn new() -> TheTimeline
pub fn collection(coll: TheCollection) -> TheTimeline
Sourcepub fn get(
&self,
name: String,
key: String,
at: &TheTime,
inter: TheInterpolation,
) -> Option<TheValue>
pub fn get( &self, name: String, key: String, at: &TheTime, inter: TheInterpolation, ) -> Option<TheValue>
Gets the value for the given key at the given time.
Sourcepub fn get_default(
&self,
name: String,
key: String,
at: &TheTime,
default: TheValue,
inter: TheInterpolation,
) -> TheValue
pub fn get_default( &self, name: String, key: String, at: &TheTime, default: TheValue, inter: TheInterpolation, ) -> TheValue
Gets the value for the given key at the given time.
Sourcepub fn add(&mut self, time: TheTime, collection: TheCollection)
pub fn add(&mut self, time: TheTime, collection: TheCollection)
Adds a collection of values at the given time.
Sourcepub fn set(
&mut self,
time: &TheTime,
key: &str,
collection: &str,
value: TheValue,
)
pub fn set( &mut self, time: &TheTime, key: &str, collection: &str, value: TheValue, )
Sets a value at the given time.
Sourcepub fn clear_collection(&mut self, time: &TheTime, collection: &str)
pub fn clear_collection(&mut self, time: &TheTime, collection: &str)
Clears the collection with the given name and at the given time.
Sourcepub fn fill(&self, time: &TheTime, collection: &mut TheCollection)
pub fn fill(&self, time: &TheTime, collection: &mut TheCollection)
Replaces the keys of the collection with the keys at the given time.
Sourcepub fn adjust_for_time(&self, at: &TheTime) -> Vec<TheCollection>
pub fn adjust_for_time(&self, at: &TheTime) -> Vec<TheCollection>
Returns a Vec
Sourcepub fn get_collection_at(
&self,
time: &TheTime,
name: String,
) -> Option<TheCollection>
pub fn get_collection_at( &self, time: &TheTime, name: String, ) -> Option<TheCollection>
Returns the collection at the given time.
Sourcepub fn contains_collection(&self, name: &str) -> bool
pub fn contains_collection(&self, name: &str) -> bool
Checks if the timeline contains the given collection.