TheUI

Struct TheUI 

pub struct TheUI {
    pub canvas: TheCanvas,
    pub dialog_text: String,
    pub dialog: Option<TheCanvas>,
    pub style: Box<dyn TheStyle>,
    pub context_menu: Option<TheContextMenu>,
    pub menu_widget_id: Option<TheId>,
    pub is_dirty: bool,
    pub shift: bool,
    pub ctrl: bool,
    pub alt: bool,
    pub logo: bool,
    pub mouse_coord: Vec2<i32>,
    /* private fields */
}

Fields

canvas: TheCanvasdialog_text: Stringdialog: Option<TheCanvas>style: Box<dyn TheStyle>context_menu: Option<TheContextMenu>menu_widget_id: Option<TheId>is_dirty: boolshift: boolctrl: boolalt: boolmouse_coord: Vec2<i32>

Implementations

Source

impl TheUI

pub fn new() -> TheUI

pub fn init(&mut self, ctx: &mut TheContext)

pub fn add_state_listener(&mut self, name: String) -> Receiver<TheEvent>

Adds a widget state listener of the given name. Returns the Receiver which the app can user to react to widget state changes. An app can add several listeners.

pub fn set_statusbar_name(&mut self, name: String)

pub fn relayout(&mut self, ctx: &mut TheContext)

pub fn focus_widget_supports_text_input(&mut self, ctx: &mut TheContext) -> bool

Returns true if the current focus widget supports text input.

pub fn focus_widget_supports_clipboard(&mut self, ctx: &mut TheContext) -> bool

Returns true if the current focus widget supports clipboard operations.

pub fn focus_widget_supports_undo_redo(&mut self, ctx: &mut TheContext) -> bool

Returns true if the current focus widget supports internal undo / redo operations.

pub fn cut(&mut self, ctx: &mut TheContext)

Initiate a cut operation on the current focus widget.

pub fn copy(&mut self, ctx: &mut TheContext)

Initiate a copy operation on the current focus widget.

pub fn paste(&mut self, ctx: &mut TheContext)

Initiate a paste operation on the current focus widget.

pub fn undo(&mut self, ctx: &mut TheContext)

Initiate a widget based undo.

pub fn redo(&mut self, ctx: &mut TheContext)

Initiate a widget based redo.

pub fn draw(&mut self, pixels: &mut [u8], ctx: &mut TheContext)

pub fn process_events(&mut self, ctx: &mut TheContext)

Processes widget state events, these are mostly send from TheUIContext based on state changes provided by the widgets.

pub fn set_disabled(&mut self, id: &str, ctx: &mut TheContext)

Set the given id as disabled.

pub fn set_enabled(&mut self, id: &str, ctx: &mut TheContext)

Remove the given id from the disabled list.

pub fn update(&mut self, ctx: &mut TheContext) -> bool

pub fn context(&mut self, x: f32, y: f32, ctx: &mut TheContext) -> bool

pub fn touch_down(&mut self, x: f32, y: f32, ctx: &mut TheContext) -> bool

pub fn touch_dragged(&mut self, x: f32, y: f32, ctx: &mut TheContext) -> bool

pub fn touch_up(&mut self, x: f32, y: f32, ctx: &mut TheContext) -> bool

pub fn hover(&mut self, x: f32, y: f32, ctx: &mut TheContext) -> bool

pub fn mouse_wheel(&mut self, delta: (i32, i32), ctx: &mut TheContext) -> bool

pub fn key_down( &mut self, char: Option<char>, key: Option<TheKeyCode>, ctx: &mut TheContext, ) -> bool

pub fn key_up( &mut self, char: Option<char>, key: Option<TheKeyCode>, ctx: &mut TheContext, ) -> bool

pub fn modifier_changed( &mut self, shift: bool, ctrl: bool, alt: bool, logo: bool, ctx: &mut TheContext, ) -> bool

pub fn get_layout_at_coord(&mut self, coord: Vec2<i32>) -> Option<TheId>

Returns the layout at the given position.

pub fn get_widget_at_coord( &mut self, coord: Vec2<i32>, ) -> Option<&mut Box<dyn TheWidget>>

Returns the absolute widget at the given position.

pub fn get_widget_abs( &mut self, name: Option<&String>, uuid: Option<&Uuid>, ) -> Option<&mut Box<dyn TheWidget>>

pub fn get_widget(&mut self, name: &str) -> Option<&mut Box<dyn TheWidget>>

Gets a given widget by name

pub fn get_widget_id(&mut self, id: Uuid) -> Option<&mut Box<dyn TheWidget>>

Gets a given widget by id

pub fn get_text_line_edit( &mut self, name: &str, ) -> Option<&mut dyn TheTextLineEditTrait>

Gets a given text line edit by name

pub fn get_text_area_edit( &mut self, name: &str, ) -> Option<&mut dyn TheTextAreaEditTrait>

Gets a given text area edit by name

pub fn get_icon_view(&mut self, name: &str) -> Option<&mut dyn TheIconViewTrait>

Gets a given icon view by name

pub fn get_menu(&mut self, name: &str) -> Option<&mut dyn TheMenuTrait>

Gets a given menu by name

pub fn get_render_view( &mut self, name: &str, ) -> Option<&mut dyn TheRenderViewTrait>

Gets a given render view by name

pub fn get_text(&mut self, name: &str) -> Option<&mut dyn TheTextTrait>

Gets a given text by name

pub fn get_group_button( &mut self, name: &str, ) -> Option<&mut dyn TheGroupButtonTrait>

Gets a given group button by name

pub fn get_statusbar( &mut self, name: &str, ) -> Option<&mut dyn TheStatusbarTrait>

Gets a given statusbar by name

pub fn get_drop_down_menu( &mut self, name: &str, ) -> Option<&mut dyn TheDropdownMenuTrait>

Gets a given drop down menu by name

pub fn get_time_slider( &mut self, name: &str, ) -> Option<&mut dyn TheTimeSliderTrait>

Gets a given time slider by name

pub fn get_palette_picker( &mut self, name: &str, ) -> Option<&mut dyn ThePalettePickerTrait>

Gets a given palette picker by name

pub fn get_layout(&mut self, name: &str) -> Option<&mut Box<dyn TheLayout>>

Gets a given layout by name

pub fn relayout_layout(&mut self, name: &str, ctx: &mut TheContext)

Relayouts the given layout.

pub fn get_list_layout( &mut self, name: &str, ) -> Option<&mut dyn TheListLayoutTrait>

Gets a given TheListLayout by name

pub fn get_tree_layout( &mut self, name: &str, ) -> Option<&mut dyn TheTreeLayoutTrait>

Gets a given TheTreeLayout by name

pub fn get_rowlist_layout( &mut self, name: &str, ) -> Option<&mut dyn TheRowListLayoutTrait>

Gets a given TheRowListLayout by name

pub fn get_stack_layout( &mut self, name: &str, ) -> Option<&mut dyn TheStackLayoutTrait>

Gets a given TheStackLayout by name

pub fn select_first_list_item(&mut self, name: &str, ctx: &mut TheContext)

Selects the first item of a list layout.

pub fn select_list_item_at( &mut self, name: &str, index: i32, ctx: &mut TheContext, )

pub fn get_rgba_layout( &mut self, name: &str, ) -> Option<&mut dyn TheRGBALayoutTrait>

Gets a given TheRGBALayout by name

pub fn get_sharedhlayout( &mut self, name: &str, ) -> Option<&mut dyn TheSharedHLayoutTrait>

Gets a given TheSharedHLayout by name

pub fn get_sharedvlayout( &mut self, name: &str, ) -> Option<&mut dyn TheSharedVLayoutTrait>

Gets a given TheSharedVLayout by name

pub fn get_hlayout(&mut self, name: &str) -> Option<&mut dyn TheHLayoutTrait>

Gets a given TheHLayout by name

pub fn get_vlayout(&mut self, name: &str) -> Option<&mut dyn TheVLayoutTrait>

Gets a given TheVLayout by name

pub fn get_text_layout( &mut self, name: &str, ) -> Option<&mut dyn TheTextLayoutTrait>

Gets a given TheTextLayout by name

pub fn set_node_canvas(&mut self, name: &str, canvas: TheNodeCanvas)

Sets the nodes for a node canvas.

pub fn set_node_overlay(&mut self, name: &str, overlay: Option<TheRGBABuffer>)

Sets the overlay for the node canvas.

pub fn set_node_preview( &mut self, name: &str, index: usize, buffer: TheRGBABuffer, )

Sets the preview for a node in a node canvas.

pub fn get_node_canvas_view( &mut self, name: &str, ) -> Option<&mut dyn TheNodeCanvasViewTrait>

Gets a given TheNodeCanvasView by name

pub fn set_widget_disabled_state( &mut self, name: &str, ctx: &mut TheContext, disabled: bool, )

Set the disabled state of the given widget.

pub fn set_widget_context_menu( &mut self, name: &str, menu: Option<TheContextMenu>, )

Sets the context menu for the widget.

pub fn get_widget_value(&mut self, name: &str) -> Option<TheValue>

Get the value of the given widget.

pub fn set_widget_value( &mut self, name: &str, ctx: &mut TheContext, value: TheValue, ) -> bool

Set the value of the given widget.

pub fn show_dialog( &mut self, text: &str, canvas: TheCanvas, buttons: Vec<TheDialogButtonRole>, ctx: &mut TheContext, )

Opens a dialog which will have the canvas as context and the given text as title.

pub fn clear_dialog(&mut self)

Clears / closes the dialog.

pub fn draw_dialog(&mut self, ctx: &mut TheContext)

Draws the current dialog.