pub struct TheUndo {
pub id: TheId,
pub undo_data: String,
pub redo_data: String,
}Expand description
Represents a single undo/redo operation.
It stores the type of the operation along with the data required to undo or redo the action.
Fields
id: TheIdundo_data: Stringredo_data: StringImplementations