pub struct Transition<T, F, Progress = f32> {
pub start: T,
pub end: T,
pub progress: Progress,
pub progress_mapper: F,
}Expand description
A convenience structure for storing a progression from one value to another.
Fields
start: TThe value when progress gets close to 0.
end: TThe value when progress gets close to 1.
progress: ProgressExpected to be between 0 and 1.
progress_mapper: FFunctor that maps the current progress value to a LERP factor.
Implementations
Sourceimpl<T, F, Progress> Transition<T, F, Progress>
impl<T, F, Progress> Transition<T, F, Progress>
Sourcepub fn with_mapper(
start: T,
end: T,
progress_mapper: F,
) -> Transition<T, F, Progress>where
Progress: Zero,
pub fn with_mapper(
start: T,
end: T,
progress_mapper: F,
) -> Transition<T, F, Progress>where
Progress: Zero,
Creates a new Transition from start and end values and progress_mapper, setting progress to zero.
Sourcepub fn with_mapper_and_progress(
start: T,
end: T,
progress_mapper: F,
progress: Progress,
) -> Transition<T, F, Progress>
pub fn with_mapper_and_progress( start: T, end: T, progress_mapper: F, progress: Progress, ) -> Transition<T, F, Progress>
Creates a new Transition from start, end, progress_mapper and progress values.
Sourcepub fn into_range(self) -> Range<T>
pub fn into_range(self) -> Range<T>
Converts this into a Range, dropping the progress and progress_mapper values.
Sourceimpl<T, F, Progress> Transition<T, F, Progress>where
F: ProgressMapper<Progress>,
impl<T, F, Progress> Transition<T, F, Progress>where
F: ProgressMapper<Progress>,
Sourcepub fn into_current(self) -> T
pub fn into_current(self) -> T
Gets the transition’s current state, clamping progress to [0;1].
Sourcepub fn into_current_unclamped(self) -> Twhere
T: Lerp<Progress, Output = T>,
pub fn into_current_unclamped(self) -> Twhere
T: Lerp<Progress, Output = T>,
Gets the transition’s current state using the progress value as-is.
Sourcepub fn into_current_precise(self) -> T
pub fn into_current_precise(self) -> T
Gets the transition’s current state, clamping progress to [0;1].
Sourcepub fn into_current_unclamped_precise(self) -> Twhere
T: Lerp<Progress, Output = T>,
pub fn into_current_unclamped_precise(self) -> Twhere
T: Lerp<Progress, Output = T>,
Gets the transition’s current state using the progress value as-is.
Sourcepub fn current<'a>(&'a self) -> T
pub fn current<'a>(&'a self) -> T
Gets the transition’s current state, clamping progress to [0;1].
Sourcepub fn current_unclamped<'a>(&'a self) -> T
pub fn current_unclamped<'a>(&'a self) -> T
Gets the transition’s current state using the progress value as-is.
Sourcepub fn current_precise<'a>(&'a self) -> T
pub fn current_precise<'a>(&'a self) -> T
Gets the transition’s current state, clamping progress to [0;1].
Sourcepub fn current_unclamped_precise<'a>(&'a self) -> T
pub fn current_unclamped_precise<'a>(&'a self) -> T
Gets the transition’s current state using the progress value as-is.
Sourceimpl<T, Progress> Transition<T, IdentityProgressMapper, Progress>
impl<T, Progress> Transition<T, IdentityProgressMapper, Progress>
Sourcepub fn new(start: T, end: T) -> Transition<T, IdentityProgressMapper, Progress>where
Progress: Zero,
pub fn new(start: T, end: T) -> Transition<T, IdentityProgressMapper, Progress>where
Progress: Zero,
Creates a new LinearTransition from start and end values, setting progress to zero.
Sourcepub fn with_progress(
start: T,
end: T,
progress: Progress,
) -> Transition<T, IdentityProgressMapper, Progress>
pub fn with_progress( start: T, end: T, progress: Progress, ) -> Transition<T, IdentityProgressMapper, Progress>
Creates a new LinearTransition from start, end and progress values.