TheGroupButtonTrait

Trait TheGroupButtonTrait 

pub trait TheGroupButtonTrait: TheWidget {
    // Required methods
    fn add_text(&mut self, text: String);
    fn add_text_status(&mut self, text: String, status: String);
    fn add_text_status_icon(
        &mut self,
        text: String,
        status: String,
        icon: String,
    );
    fn set_item_width(&mut self, width: usize);
    fn set_index(&mut self, index: i32);
    fn index(&self) -> i32;
}

Required Methods

fn add_text(&mut self, text: String)

Add a new text based item.

fn add_text_status(&mut self, text: String, status: String)

Add a new text based item with an associated status text.

fn add_text_status_icon(&mut self, text: String, status: String, icon: String)

Add a new text based item with an associated status text and an icon.

fn set_item_width(&mut self, width: usize)

Set the width of each itme.

fn set_index(&mut self, index: i32)

Set the index.

fn index(&self) -> i32

Get the selected index.

Implementors