TheStackLayoutTrait

Trait TheStackLayoutTrait 

pub trait TheStackLayoutTrait: TheLayout {
    // Required methods
    fn add_canvas(&mut self, canvas: TheCanvas) -> usize;
    fn index(&self) -> usize;
    fn set_index(&mut self, index: usize);
    fn canvas_at_mut(&mut self, index: usize) -> Option<&mut TheCanvas>;
}
TheHLayout specific functions.

Required Methods

fn add_canvas(&mut self, canvas: TheCanvas) -> usize

Add a canvas to the stack and returns the index.

fn index(&self) -> usize

Returns the index of the current layout.

fn set_index(&mut self, index: usize)

Set the index of the current layout.

fn canvas_at_mut(&mut self, index: usize) -> Option<&mut TheCanvas>

Get a mutable reference to the canvas at the given index.

Implementors