TheTextLayoutTrait

Trait TheTextLayoutTrait 

pub trait TheTextLayoutTrait: TheLayout {
    // Required methods
    fn clear(&mut self);
    fn add_pair(&mut self, text: String, widget: Box<dyn TheWidget>);
    fn set_fixed_text_width(&mut self, text_width: i32);
    fn set_text_size(&mut self, text_size: f32);
    fn set_text_margin(&mut self, text_margin: i32);
    fn set_text_align(&mut self, align: TheHorizontalAlign);
}
TheTextLayout specific functions.

Required Methods

fn clear(&mut self)

Clear the text and widget pairs.

fn add_pair(&mut self, text: String, widget: Box<dyn TheWidget>)

Add a text / widget pair.

fn set_fixed_text_width(&mut self, text_width: i32)

Set the fixed text width.

fn set_text_size(&mut self, text_size: f32)

Set the text size to use for the left handed text.

fn set_text_margin(&mut self, text_margin: i32)

Set the text margin between the text and the widget.

fn set_text_align(&mut self, align: TheHorizontalAlign)

The horizontal text alignment

Implementors