pub struct Sidebar {
pub width: i32,
pub startup: bool,
/* private fields */
}Fields
width: i32startup: boolImplementations
Sourceimpl Sidebar
impl Sidebar
pub fn new() -> Self
pub fn init_ui( &mut self, ui: &mut TheUI, ctx: &mut TheContext, server_ctx: &mut ServerContext, )
pub fn handle_event( &mut self, event: &TheEvent, ui: &mut TheUI, ctx: &mut TheContext, project: &mut Project, server_ctx: &mut ServerContext, ) -> bool
Sourcepub fn load_from_project(
&mut self,
ui: &mut TheUI,
ctx: &mut TheContext,
server_ctx: &mut ServerContext,
project: &mut Project,
)
pub fn load_from_project( &mut self, ui: &mut TheUI, ctx: &mut TheContext, server_ctx: &mut ServerContext, project: &mut Project, )
Apply th given project to the UI
Sourcepub fn apply_screen(
&mut self,
ui: &mut TheUI,
ctx: &mut TheContext,
screen: Option<&Screen>,
)
pub fn apply_screen( &mut self, ui: &mut TheUI, ctx: &mut TheContext, screen: Option<&Screen>, )
Apply the given screen to the UI
Sourcepub fn apply_avatars(
&mut self,
ui: &mut TheUI,
_ctx: &mut TheContext,
server_ctx: &mut ServerContext,
project: &mut Project,
)
pub fn apply_avatars( &mut self, ui: &mut TheUI, _ctx: &mut TheContext, server_ctx: &mut ServerContext, project: &mut Project, )
Apply the avatars
Sourcepub fn apply_regions(
&mut self,
ui: &mut TheUI,
ctx: &mut TheContext,
server_ctx: &mut ServerContext,
project: &mut Project,
)
pub fn apply_regions( &mut self, ui: &mut TheUI, ctx: &mut TheContext, server_ctx: &mut ServerContext, project: &mut Project, )
Apply the current regions to the tree.
Sourcepub fn apply_characters(
&mut self,
ui: &mut TheUI,
_ctx: &mut TheContext,
server_ctx: &mut ServerContext,
project: &mut Project,
)
pub fn apply_characters( &mut self, ui: &mut TheUI, _ctx: &mut TheContext, server_ctx: &mut ServerContext, project: &mut Project, )
Apply the current characters to the tree.
Sourcepub fn apply_items(
&mut self,
ui: &mut TheUI,
_ctx: &mut TheContext,
server_ctx: &mut ServerContext,
project: &mut Project,
)
pub fn apply_items( &mut self, ui: &mut TheUI, _ctx: &mut TheContext, server_ctx: &mut ServerContext, project: &mut Project, )
Apply the current items to the tree.
Sourcepub fn apply_tilemaps(
&mut self,
ui: &mut TheUI,
_ctx: &mut TheContext,
server_ctx: &mut ServerContext,
project: &mut Project,
)
pub fn apply_tilemaps( &mut self, ui: &mut TheUI, _ctx: &mut TheContext, server_ctx: &mut ServerContext, project: &mut Project, )
Apply the current tilemaps to the tree.
Sourcepub fn apply_screens(
&mut self,
ui: &mut TheUI,
_ctx: &mut TheContext,
server_ctx: &mut ServerContext,
project: &mut Project,
)
pub fn apply_screens( &mut self, ui: &mut TheUI, _ctx: &mut TheContext, server_ctx: &mut ServerContext, project: &mut Project, )
Apply the current screens to the tree.
Sourcepub fn apply_assets(
&mut self,
ui: &mut TheUI,
_ctx: &mut TheContext,
server_ctx: &mut ServerContext,
project: &mut Project,
)
pub fn apply_assets( &mut self, ui: &mut TheUI, _ctx: &mut TheContext, server_ctx: &mut ServerContext, project: &mut Project, )
Apply the current assets to the tree.
Sourcepub fn apply_region(
&mut self,
_ui: &mut TheUI,
_ctx: &mut TheContext,
_region_id: Option<Uuid>,
_project: &mut Project,
)
pub fn apply_region( &mut self, _ui: &mut TheUI, _ctx: &mut TheContext, _region_id: Option<Uuid>, _project: &mut Project, )
Apply the given item to the UI
Sourcepub fn show_filtered_tiles(
&mut self,
ui: &mut TheUI,
ctx: &mut TheContext,
tilemap: Option<&Tilemap>,
)
pub fn show_filtered_tiles( &mut self, ui: &mut TheUI, ctx: &mut TheContext, tilemap: Option<&Tilemap>, )
Shows the filtered tiles of the given tilemap.
Sourcepub fn show_actions(
&mut self,
ui: &mut TheUI,
ctx: &mut TheContext,
project: &Project,
server_ctx: &mut ServerContext,
)
pub fn show_actions( &mut self, ui: &mut TheUI, ctx: &mut TheContext, project: &Project, server_ctx: &mut ServerContext, )
Shows the filtered actions for the current selection.
Sourcepub fn apply_asset(
&mut self,
_ui: &mut TheUI,
_ctx: &mut TheContext,
_asset: Option<&Asset>,
)
pub fn apply_asset( &mut self, _ui: &mut TheUI, _ctx: &mut TheContext, _asset: Option<&Asset>, )
Apply the given asset to the UI
Deselects the section buttons
Sourcepub fn get_selected_in_list_layout(
&self,
ui: &mut TheUI,
layout_name: &str,
) -> Option<TheId>
pub fn get_selected_in_list_layout( &self, ui: &mut TheUI, layout_name: &str, ) -> Option<TheId>
Returns the selected id in the given list layout
Sourcepub fn deselect_all(&self, layout_name: &str, ui: &mut TheUI)
pub fn deselect_all(&self, layout_name: &str, ui: &mut TheUI)
Deselects all items in the given list layout.
Sourcepub fn clear_debug_messages(&self, ui: &mut TheUI, ctx: &mut TheContext)
pub fn clear_debug_messages(&self, ui: &mut TheUI, ctx: &mut TheContext)
Clears the debug messages.
pub fn apply_action( &self, action: &Box<dyn Action>, map: &mut Map, ui: &mut TheUI, ctx: &mut TheContext, server_ctx: &mut ServerContext, param_update: bool, ) -> bool
Sourcepub fn update_tiles(
&mut self,
_ui: &mut TheUI,
ctx: &mut TheContext,
project: &mut Project,
)
pub fn update_tiles( &mut self, _ui: &mut TheUI, ctx: &mut TheContext, project: &mut Project, )
Tilemaps in the project have been updated, propagate the change to all relevant parties.