pub struct UndoManager {
pub max_undo: usize,
/* private fields */
}Fields
max_undo: usizeImplementations
Sourceimpl UndoManager
impl UndoManager
pub fn new() -> Self
pub fn add_undo(&mut self, atom: ProjectUndoAtom, ctx: &mut TheContext)
pub fn mark_saved(&mut self)
pub fn set_undo_state_to_ui(&self, ctx: &mut TheContext)
pub fn undo( &mut self, server_ctx: &mut ServerContext, project: &mut Project, ui: &mut TheUI, ctx: &mut TheContext, )
pub fn redo( &mut self, server_ctx: &mut ServerContext, project: &mut Project, ui: &mut TheUI, ctx: &mut TheContext, )
Sourcepub fn can_save(&self, ctx: &mut TheContext)
pub fn can_save(&self, ctx: &mut TheContext)
Checks if the undo manager is empty and disables the save buttons if it is.
Sourcepub fn has_unsaved(&self) -> bool
pub fn has_unsaved(&self) -> bool
Returns true if current state differs from the last saved checkpoint.