pub fn scenemanager_render_map(project: &Project, server_ctx: &ServerContext)Expand description
Renders the current map in the scenemanager depending on the current viewmode.
pub fn scenemanager_render_map(project: &Project, server_ctx: &ServerContext)Renders the current map in the scenemanager depending on the current viewmode.