pub fn set_code(
ui: &mut TheUI,
ctx: &mut TheContext,
project: &mut Project,
server_ctx: &ServerContext,
)Expand description
Sets the code for the code editor based on the current editor mode
pub fn set_code(
ui: &mut TheUI,
ctx: &mut TheContext,
project: &mut Project,
server_ctx: &ServerContext,
)Sets the code for the code editor based on the current editor mode