pub struct Project {Show 14 fields
pub name: String,
pub regions: Vec<Region>,
pub tilemaps: Vec<Tilemap>,
pub tiles: IndexMap<Uuid, Tile>,
pub time: TheTime,
pub characters: IndexMap<Uuid, Character>,
pub items: IndexMap<Uuid, Item>,
pub screens: IndexMap<Uuid, Screen>,
pub assets: IndexMap<Uuid, Asset>,
pub palette: ThePalette,
pub target_fps: u32,
pub tick_ms: u32,
pub config: String,
pub avatars: IndexMap<Uuid, Avatar>,
}Fields
name: Stringregions: Vec<Region>tilemaps: Vec<Tilemap>tiles: IndexMap<Uuid, Tile>Tiles in the project
time: TheTimecharacters: IndexMap<Uuid, Character>items: IndexMap<Uuid, Item>screens: IndexMap<Uuid, Screen>assets: IndexMap<Uuid, Asset>palette: ThePalettetarget_fps: u32tick_ms: u32config: Stringavatars: IndexMap<Uuid, Avatar>Implementations
Sourceimpl Project
impl Project
pub fn new() -> Project
Sourcepub fn add_character(&mut self, character: Character)
pub fn add_character(&mut self, character: Character)
Add Character
Sourcepub fn remove_character(&mut self, id: &Uuid)
pub fn remove_character(&mut self, id: &Uuid)
Removes the given character from the project.
Sourcepub fn sorted_character_list(&self) -> Vec<(Uuid, String)>
pub fn sorted_character_list(&self) -> Vec<(Uuid, String)>
Returns a list of all characters sorted by name.
Sourcepub fn sorted_item_list(&self) -> Vec<(Uuid, String)>
pub fn sorted_item_list(&self) -> Vec<(Uuid, String)>
Returns a list of all items sorted by name.
Sourcepub fn add_avatar(&mut self, avatar: Avatar)
pub fn add_avatar(&mut self, avatar: Avatar)
Add Avatar
Sourcepub fn remove_avatar(&mut self, id: &Uuid)
pub fn remove_avatar(&mut self, id: &Uuid)
Removes the given avatar from the project.
Sourcepub fn find_avatar_for_animation(&self, animation_id: &Uuid) -> Option<&Avatar>
pub fn find_avatar_for_animation(&self, animation_id: &Uuid) -> Option<&Avatar>
Finds the avatar that contains the given animation id.
Sourcepub fn get_editing_texture(
&self,
editing_ctx: &PixelEditingContext,
) -> Option<&Texture>
pub fn get_editing_texture( &self, editing_ctx: &PixelEditingContext, ) -> Option<&Texture>
Returns an immutable reference to the texture identified by the editing context.
Sourcepub fn get_editing_texture_mut(
&mut self,
editing_ctx: &PixelEditingContext,
) -> Option<&mut Texture>
pub fn get_editing_texture_mut( &mut self, editing_ctx: &PixelEditingContext, ) -> Option<&mut Texture>
Returns a mutable reference to the texture identified by the editing context.
Sourcepub fn get_editing_avatar_frame(
&self,
editing_ctx: &PixelEditingContext,
) -> Option<&AvatarAnimationFrame>
pub fn get_editing_avatar_frame( &self, editing_ctx: &PixelEditingContext, ) -> Option<&AvatarAnimationFrame>
Returns an immutable avatar frame for avatar frame editing contexts.
Sourcepub fn get_editing_avatar_frame_mut(
&mut self,
editing_ctx: &PixelEditingContext,
) -> Option<&mut AvatarAnimationFrame>
pub fn get_editing_avatar_frame_mut( &mut self, editing_ctx: &PixelEditingContext, ) -> Option<&mut AvatarAnimationFrame>
Returns a mutable avatar frame for avatar frame editing contexts.
Sourcepub fn get_editing_avatar_perspective(
&self,
editing_ctx: &PixelEditingContext,
) -> Option<&AvatarPerspective>
pub fn get_editing_avatar_perspective( &self, editing_ctx: &PixelEditingContext, ) -> Option<&AvatarPerspective>
Returns an immutable avatar perspective for avatar frame editing contexts.
Sourcepub fn get_editing_avatar_perspective_mut(
&mut self,
editing_ctx: &PixelEditingContext,
) -> Option<&mut AvatarPerspective>
pub fn get_editing_avatar_perspective_mut( &mut self, editing_ctx: &PixelEditingContext, ) -> Option<&mut AvatarPerspective>
Returns a mutable avatar perspective for avatar frame editing contexts.
Sourcepub fn remove_item(&mut self, id: &Uuid)
pub fn remove_item(&mut self, id: &Uuid)
Removes the given item from the project.
Sourcepub fn add_tilemap(&mut self, tilemap: Tilemap)
pub fn add_tilemap(&mut self, tilemap: Tilemap)
Add a tilemap
Sourcepub fn get_tilemap(&self, uuid: Uuid) -> Option<&Tilemap>
pub fn get_tilemap(&self, uuid: Uuid) -> Option<&Tilemap>
Get the tilemap of the given uuid.
Sourcepub fn get_tilemap_mut(&mut self, uuid: Uuid) -> Option<&mut Tilemap>
pub fn get_tilemap_mut(&mut self, uuid: Uuid) -> Option<&mut Tilemap>
Get the tilemap of the given uuid.
Sourcepub fn remove_tilemap(&mut self, id: TheId)
pub fn remove_tilemap(&mut self, id: TheId)
Removes the given tilemap from the project.
Sourcepub fn contains_region(&self, uuid: &Uuid) -> bool
pub fn contains_region(&self, uuid: &Uuid) -> bool
Contains the region of the given uuid.
Sourcepub fn get_region(&self, uuid: &Uuid) -> Option<&Region>
pub fn get_region(&self, uuid: &Uuid) -> Option<&Region>
Get the region of the given uuid.
Sourcepub fn get_region_mut(&mut self, uuid: &Uuid) -> Option<&mut Region>
pub fn get_region_mut(&mut self, uuid: &Uuid) -> Option<&mut Region>
Get the region of the given uuid as mutable.
Sourcepub fn get_region_ctx(&self, ctx: &ServerContext) -> Option<&Region>
pub fn get_region_ctx(&self, ctx: &ServerContext) -> Option<&Region>
Get the region of the given uuid.
Sourcepub fn get_region_ctx_mut(&mut self, ctx: &ServerContext) -> Option<&mut Region>
pub fn get_region_ctx_mut(&mut self, ctx: &ServerContext) -> Option<&mut Region>
Get the region of the given uuid as mutable.
Sourcepub fn get_screen_ctx(&self, ctx: &ServerContext) -> Option<&Screen>
pub fn get_screen_ctx(&self, ctx: &ServerContext) -> Option<&Screen>
Get the screen of the given uuid.
Sourcepub fn get_screen_ctx_mut(&mut self, ctx: &ServerContext) -> Option<&mut Screen>
pub fn get_screen_ctx_mut(&mut self, ctx: &ServerContext) -> Option<&mut Screen>
Get the mut screen of the given uuid.
Sourcepub fn remove_region(&mut self, id: &Uuid)
pub fn remove_region(&mut self, id: &Uuid)
Remove a region
Sourcepub fn get_map(&self, ctx: &ServerContext) -> Option<&Map>
pub fn get_map(&self, ctx: &ServerContext) -> Option<&Map>
Get the map of the current context.
Sourcepub fn get_map_mut(&mut self, ctx: &ServerContext) -> Option<&mut Map>
pub fn get_map_mut(&mut self, ctx: &ServerContext) -> Option<&mut Map>
Get the mutable map of the current context.
Sourcepub fn add_screen(&mut self, screen: Screen)
pub fn add_screen(&mut self, screen: Screen)
Add Screen
Sourcepub fn remove_screen(&mut self, id: &Uuid)
pub fn remove_screen(&mut self, id: &Uuid)
Removes the given code from the project.
Sourcepub fn sorted_screens_list(&self) -> Vec<(Uuid, String)>
pub fn sorted_screens_list(&self) -> Vec<(Uuid, String)>
Returns a list of all screens sorted by name.
Sourcepub fn remove_asset(&mut self, id: &Uuid)
pub fn remove_asset(&mut self, id: &Uuid)
Removes the given code from the project.
Sourcepub fn sorted_assets_list(&self) -> Vec<(Uuid, String)>
pub fn sorted_assets_list(&self) -> Vec<(Uuid, String)>
Returns a list of all assets sorted by name.
Sourcepub fn remove_tile(&mut self, id: &Uuid)
pub fn remove_tile(&mut self, id: &Uuid)
Removes the given tile from the project.
Sourcepub fn get_tile_mut(&mut self, id: &Uuid) -> Option<&mut Tile>
pub fn get_tile_mut(&mut self, id: &Uuid) -> Option<&mut Tile>
Gets the given mutable tile from the project.
Sourcepub fn extract_tiles(&self) -> IndexMap<Uuid, TheRGBATile>
pub fn extract_tiles(&self) -> IndexMap<Uuid, TheRGBATile>
Extract all tiles from all tilemaps and store them in a hash.
Sourcepub fn extract_tiles_vec(&self) -> Vec<TheRGBATile>
pub fn extract_tiles_vec(&self) -> Vec<TheRGBATile>
Extract all tiles from all tilemaps and store them in a vec.
Sourcepub fn extract_tile(&self, id: &Uuid) -> Option<TheRGBATile>
pub fn extract_tile(&self, id: &Uuid) -> Option<TheRGBATile>
Extract the given tile from the tilemaps.