pub struct TheAcceleratorKey { /* private fields */ }Implementations
Sourceimpl TheAcceleratorKey
impl TheAcceleratorKey
Sourcepub const SHIFT: TheAcceleratorKey
pub const SHIFT: TheAcceleratorKey
Shift Key
Sourcepub const CTRL: TheAcceleratorKey
pub const CTRL: TheAcceleratorKey
Ctrl Key / Control on Mac
Sourcepub const ALT: TheAcceleratorKey
pub const ALT: TheAcceleratorKey
Alt Key / Option on Mac
Sourcepub const CMD: TheAcceleratorKey
pub const CMD: TheAcceleratorKey
Cmd on Mac
Sourcepub const CTRLCMD: TheAcceleratorKey
pub const CTRLCMD: TheAcceleratorKey
CtrlAndCmd
Sourcepub const ALL: TheAcceleratorKey
pub const ALL: TheAcceleratorKey
The combination of A, B, and C.
Sourcepub const fn empty() -> TheAcceleratorKey
pub const fn empty() -> TheAcceleratorKey
Returns an empty set of flags.
Sourcepub const fn all() -> TheAcceleratorKey
pub const fn all() -> TheAcceleratorKey
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<TheAcceleratorKey>
pub fn from_bits(bits: u32) -> Option<TheAcceleratorKey>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> TheAcceleratorKey
pub const fn from_bits_truncate(bits: u32) -> TheAcceleratorKey
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const fn intersects(&self, other: TheAcceleratorKey) -> bool
pub const fn intersects(&self, other: TheAcceleratorKey) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: TheAcceleratorKey) -> bool
pub const fn contains(&self, other: TheAcceleratorKey) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: TheAcceleratorKey)
pub fn insert(&mut self, other: TheAcceleratorKey)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: TheAcceleratorKey)
pub fn remove(&mut self, other: TheAcceleratorKey)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: TheAcceleratorKey)
pub fn toggle(&mut self, other: TheAcceleratorKey)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: TheAcceleratorKey, value: bool)
pub fn set(&mut self, other: TheAcceleratorKey, value: bool)
Inserts or removes the specified flags depending on the passed value.