pub trait TheGroupButtonTrait: TheWidget {
// Required methods
fn add_text(&mut self, text: String);
fn add_text_status(&mut self, text: String, status: String);
fn add_text_status_icon(
&mut self,
text: String,
status: String,
icon: String,
);
fn set_item_width(&mut self, width: usize);
fn set_index(&mut self, index: i32);
fn index(&self) -> i32;
}Required Methods
Sourcefn add_text_status(&mut self, text: String, status: String)
fn add_text_status(&mut self, text: String, status: String)
Add a new text based item with an associated status text.
Sourcefn add_text_status_icon(&mut self, text: String, status: String, icon: String)
fn add_text_status_icon(&mut self, text: String, status: String, icon: String)
Add a new text based item with an associated status text and an icon.
Sourcefn set_item_width(&mut self, width: usize)
fn set_item_width(&mut self, width: usize)
Set the width of each itme.